@@ -3,12 +3,12 @@
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
 
  */
@@ -17,7 +17,11 @@ package com.clustercontrol.accesscontrol.dialog;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Locale;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.TableTree;
 import org.eclipse.swt.events.SelectionAdapter;
@@ -31,30 +35,36 @@ import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
-import com.clustercontrol.accesscontrol.action.AddUserProperty;
-import com.clustercontrol.accesscontrol.action.GetUserProperty;
-import com.clustercontrol.accesscontrol.action.ModifyUserProperty;
+import com.clustercontrol.accesscontrol.action.CheckPermission;
 import com.clustercontrol.accesscontrol.bean.RoleConstant;
 import com.clustercontrol.accesscontrol.bean.UserConstant;
 import com.clustercontrol.accesscontrol.bean.UserRoleList;
-import com.clustercontrol.accesscontrol.factory.UserProperty;
-
+import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
+import com.clustercontrol.accesscontrol.util.UserPropertyUtil;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.bean.PropertyTreeItem;
+import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.ws.access.InvalidRole_Exception;
+import com.clustercontrol.ws.access.UserDuplicate_Exception;
+import com.clustercontrol.ws.access.UserInfo;
 
 /**
  * アクセス[ユーザの作成・変更]ダイアログクラスです。
  * 
- * @version 2.2.0
+ * @version 4.0.0
  * @since 2.0.0
  */
 public class UserDialog extends CommonDialog {
+
+	// ログ
+	private static Log m_log = LogFactory.getLog( UserDialog.class );
+
 	/** ユーザID */
 	private String uid = ""; //$NON-NLS-1$
 
@@ -64,6 +74,8 @@ public class UserDialog extends CommonDialog {
 	/** ユーザ用プロパティシート */
 	private PropertySheet propertySheet = null;
 
+	/** ユーザ用テーブル **/
+	private TableTree table = null;
 
 	private Button buttonRead = null;
 	private Button buttonWrite = null;
@@ -72,6 +84,7 @@ public class UserDialog extends CommonDialog {
 	private Button buttonClear = null;
 
 	private final UserRoleList _userRoleList;
+	private boolean permission = false;		// 現在のユーザが変更権限をもつか否か
 
 	/**
 	 * コンストラクタ
@@ -85,8 +98,12 @@ public class UserDialog extends CommonDialog {
 
 		this.uid = uid;
 		this.isModifyDialog = isModifyDialog;
-		
-		_userRoleList = new GetUserProperty().getUserRoleList();
+
+		_userRoleList = UserPropertyUtil.getRoleList();
+
+		// 現在のユーザがアクセス管理機能の設定権限をもつか否かを取得する
+		permission = new CheckPermission().check("AccessControlWrite");
+
 	}
 
 	/**
@@ -98,7 +115,7 @@ public class UserDialog extends CommonDialog {
 	 */
 	@Override
 	protected Point getInitialSize() {
-		return new Point(500, 600);
+		return new Point(600, 600);
 	}
 
 	/**
@@ -138,7 +155,7 @@ public class UserDialog extends CommonDialog {
 
 
 		// プロパティシート
-		TableTree table = new TableTree(parent, SWT.H_SCROLL | SWT.V_SCROLL
+		table = new TableTree(parent, SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -147,29 +164,51 @@ public class UserDialog extends CommonDialog {
 		gridData.grabExcessVerticalSpace = true;
 		gridData.horizontalSpan = 6;
 		table.setLayoutData(gridData);
+		if(permission){
+			table.addSelectionListener(new SelectionAdapter(){
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					update();
+				}
+			});
+		}
 
 		this.propertySheet = new PropertySheet(table);
 
 		// プロパティ取得及び設定
 		Property property = null;
-		if (this.isModifyDialog) {
-			property = new GetUserProperty().getProperty(this.uid,
-					PropertyConstant.MODE_MODIFY);
-		} else {
-			property = new GetUserProperty().getProperty(this.uid,
-					PropertyConstant.MODE_ADD);
+		int mode = 0;
+		if(permission){
+			if (this.isModifyDialog) {
+				mode = PropertyConstant.MODE_MODIFY;
+			} else {
+				mode = PropertyConstant.MODE_ADD;
+			}
+		}else{
+			mode = PropertyConstant.MODE_SHOW;
 		}
+
+		try {
+			UserInfo info = AccessEndpointWrapper.getUserInfo(this.uid);
+			property = UserPropertyUtil.dto2property(info, mode, Locale.getDefault());
+		} catch (InvalidRole_Exception e) {
+			MessageDialog.openInformation(null, Messages.getString("message"),
+					Messages.getString("message.accesscontrol.16"));
+		} catch (Exception e) {
+			m_log.warn("customizeDialog(), " + e.getMessage(), e);
+			MessageDialog.openError(
+					null,
+					Messages.getString("failed"),
+					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+		}
+
 		this.propertySheet.setInput(property);
 		this.propertySheet.expandAll();
 
-
-
-
 		/*
-		 * 操作ボタン
+		 * 操作ボタン用コンポジット
 		 */
-
-		 Composite composite = new Composite(parent, SWT.NONE);
+		Composite composite = new Composite(parent, SWT.NONE);
 		layout = new GridLayout(1, true);
 		layout.numColumns = 1;
 		composite.setLayout(layout);
@@ -181,20 +220,16 @@ public class UserDialog extends CommonDialog {
 		gridData.horizontalSpan = 2;
 		composite.setLayoutData(gridData);
 
-
-		// すべてボタン
-		@SuppressWarnings("unused") 
+		// すべての権限ボタン
+		@SuppressWarnings("unused")
 		Label dummy = new Label(composite, SWT.NONE);
-		this.buttonAll = this
-		.createButton(composite, Messages.getString("UserDialog.all_prerogative")); //$NON-NLS-1$
+		this.buttonAll = this.createButton(composite, Messages.getString("UserDialog.all_prerogative")); //$NON-NLS-1$
 		this.buttonAll.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-
-
-				Property prop = getInputData(); 
+				Property prop = getInputData();
 				//データを取得します。
-				Object[] items =  prop.getChildren();            
+				Object[] items =  prop.getChildren();
 				for(int j = 0 ; j < items.length; j++){
 					//アクセス権のプロパティを探します。
 					if(((PropertyTreeItem)items[j]).getID().equals("access")){ //$NON-NLS-1$
@@ -204,11 +239,10 @@ public class UserDialog extends CommonDialog {
 						//各権限がにチェックを入れます。
 						for (int k = 0 ; k <items.length ;  k++){
 							((Property)items[k]).setValue(true);
-						}	  
+						}
 						//アクセス権を探す処理をExit
 						break;
 					}
-
 				}
 				propertySheet.setInput(prop);
 				propertySheet.expandAll();
@@ -216,8 +250,7 @@ public class UserDialog extends CommonDialog {
 			}
 		});
 
-		// すべての参照権限
-
+		// すべての参照権限ボタン
 		dummy = new Label(composite, SWT.NONE);
 		this.buttonRead = this
 		.createButton(composite, Messages.getString("UserDialog.read_prerogative")); //$NON-NLS-1$
@@ -225,7 +258,7 @@ public class UserDialog extends CommonDialog {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 
-				Property prop = getInputData(); 
+				Property prop = getInputData();
 				//データを取得します。(一番上位の項目)
 				Object[] items =  prop.getChildren();
 
@@ -242,10 +275,10 @@ public class UserDialog extends CommonDialog {
 						for (int k = 0 ; k <items.length ;  k++){
 							for (int i= 0 ; i < readRoles.size(); i++){
 								if(((PropertyTreeItem)items[k]).getID().equals(readRoles.get(i))){
-									((Property)items[k]).setValue(true);	
+									((Property)items[k]).setValue(true);
 									break;
 								}
-							}	  
+							}
 						}
 						//アクセス権を探す処理をExit
 						break;
@@ -258,22 +291,19 @@ public class UserDialog extends CommonDialog {
 			}
 		});
 
-		// すべての設定権限
-
+		// すべての設定権限ボタン
 		dummy = new Label(composite, SWT.NONE);
 		this.buttonWrite = this.createButton(composite, Messages.getString("UserDialog.write_prerogative")); //$NON-NLS-1$
 		this.buttonWrite.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 
-				Property prop = getInputData(); 
+				Property prop = getInputData();
 				//データを取得します。(一番上位の項目)
 				Object[] items =  prop.getChildren();
 
-
 				List<String> writeRoles= _userRoleList.getWriteRoles();
 
-
 				for(int j = 0 ; j < items.length; j++){
 					//アクセス権のプロパティを探します。
 					if(((PropertyTreeItem)items[j]).getID().equals("access")){ //$NON-NLS-1$
@@ -283,10 +313,10 @@ public class UserDialog extends CommonDialog {
 						for (int k = 0 ; k <items.length ;  k++){
 							for (int i= 0 ; i < writeRoles.size(); i++){
 								if(((PropertyTreeItem)items[k]).getID().equals(writeRoles.get(i))){
-									((Property)items[k]).setValue(true);	
+									((Property)items[k]).setValue(true);
 									break;
 								}
-							}	  
+							}
 						}
 						//アクセス権を探す処理をExit
 						break;
@@ -299,21 +329,18 @@ public class UserDialog extends CommonDialog {
 			}
 		});
 
-		// 実行権限ボタン
+		// すべての実行権限ボタン
 		dummy = new Label(composite, SWT.NONE);
 		this.buttonExec = this.createButton(composite, Messages.getString("UserDialog.exec_prerogative")); //$NON-NLS-1$
 		this.buttonExec.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 
-				Property prop = getInputData(); 
+				Property prop = getInputData();
 				//データを取得します。(一番上位の項目)
 				Object[] items =  prop.getChildren();
 
-
 				List<String> execRoles= _userRoleList.getExecRoles();
-
-
 				for(int j = 0 ; j < items.length; j++){
 					//アクセス権のプロパティを探します。
 					if(((PropertyTreeItem)items[j]).getID().equals(UserConstant.ACCESS)){
@@ -323,10 +350,10 @@ public class UserDialog extends CommonDialog {
 						for (int k = 0 ; k <items.length ;  k++){
 							for (int i= 0 ; i < execRoles.size(); i++){
 								if(((PropertyTreeItem)items[k]).getID().equals(execRoles.get(i))){
-									((Property)items[k]).setValue(true);	
+									((Property)items[k]).setValue(true);
 									break;
 								}
-							}	  
+							}
 						}
 						//アクセス権を探す処理をExit
 						break;
@@ -334,9 +361,6 @@ public class UserDialog extends CommonDialog {
 				}
 				propertySheet.setInput(prop);
 				propertySheet.expandAll();
-
-
-
 			}
 		});
 
@@ -346,9 +370,9 @@ public class UserDialog extends CommonDialog {
 		this.buttonClear.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				Property prop = getInputData(); 
+				Property prop = getInputData();
 				//データを取得します。
-				Object[] items =  prop.getChildren();            
+				Object[] items =  prop.getChildren();
 				for(int j = 0 ; j < items.length; j++){
 					//アクセス権のプロパティを探します。
 					if(((PropertyTreeItem)items[j]).getID().equals("access")){ //$NON-NLS-1$
@@ -359,17 +383,23 @@ public class UserDialog extends CommonDialog {
 							if(!((PropertyTreeItem)items[k]).getID().equals(RoleConstant.REPOSITORY_READ)){
 								((Property)items[k]).setValue(false);
 							}
-						}	  
+						}
 						//アクセス権を探す処理をExit
 						break;
 					}
-
 				}
 				propertySheet.setInput(prop);
 				propertySheet.expandAll();
 			}
 		});
 
+		// 権限に応じてボタンを有効/無効化する
+		this.buttonAll.setEnabled(permission);
+		this.buttonRead.setEnabled(permission);
+		this.buttonWrite.setEnabled(permission);
+		this.buttonExec.setEnabled(permission);
+		this.buttonClear.setEnabled(permission);
+
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
 		gridData = new GridData();
@@ -378,15 +408,34 @@ public class UserDialog extends CommonDialog {
 		gridData.horizontalSpan = 8;
 		line.setLayoutData(gridData);
 
-
-
-
 		// 画面中央に
 		Display display = shell.getDisplay();
 		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
 				(display.getBounds().height - shell.getSize().y) / 2);
 
+		// 必須入力項目を可視化
+		this.update();
+	}
 
+	/**
+	 * 更新処理
+	 * 
+	 */
+	public void update(){
+		// 必須項目を明示
+
+		// ユーザIDのインデックス：0
+		if("".equals(table.getItem(0).getText(1))){
+			table.getItem(0).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			table.getItem(0).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		// ユーザ名のインデックス：1
+		if("".equals(table.getItem(1).getText(1))){
+			table.getItem(1).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			table.getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
 	}
 
 	/**
@@ -398,20 +447,7 @@ public class UserDialog extends CommonDialog {
 	 */
 	@Override
 	protected ValidateResult validate() {
-		ValidateResult result = null;
-
-		//ユーザIDの入力チェック
-		ArrayList values = PropertyUtil.getPropertyValue(getInputData(), UserConstant.UID);
-		String value = (String)values.get(0);
-		if(value.compareTo("") == 0){ //$NON-NLS-1$
-			result = new ValidateResult();
-			result.setID(Messages.getString("message.hinemos.1")); //$NON-NLS-1$
-			result.setMessage(Messages.getString("message.accesscontrol.1")); //$NON-NLS-1$
-			result.setValid(false);
-			return result;
-		}
-
-		return result;
+		return null;
 	}
 
 	/**
@@ -426,14 +462,77 @@ public class UserDialog extends CommonDialog {
 		boolean result = false;
 
 		Property property = this.getInputData();
-		if(property != null){
-			if(!this.isModifyDialog){
-				// 作成の場合
-				result = new AddUserProperty().add(property);
+		if(property == null){
+			return result;
+		}
+
+		Property copy = PropertyUtil.copy(property);
+		PropertyUtil.deletePropertyDefine(copy);
+		UserInfo info = UserPropertyUtil.property2dto(copy);
+		if(!this.isModifyDialog){
+			// 作成の場合
+			try {
+				AccessEndpointWrapper.addUserInfo(info);
+				result = true;
+
+				// 完了メッセージ
+				MessageDialog.openInformation(
+						null,
+						Messages.getString("successful"),
+						Messages.getString("message.accesscontrol.7"));
+
+			} catch (UserDuplicate_Exception e) {
+				//ユーザID取得
+				ArrayList values = PropertyUtil.getPropertyValue(copy, UserConstant.UID);
+				String args[] = { (String)values.get(0) };
+
+				// ユーザIDが重複している場合、エラーダイアログを表示する
+				MessageDialog.openInformation(
+						null,
+						Messages.getString("message"),
+						Messages.getString("message.monitor.53", args));
+
+			} catch (Exception e) {
+				String errMessage = "";
+				if (e instanceof InvalidRole_Exception) {
+					// 権限なし
+					MessageDialog.openInformation(null, Messages.getString("message"),
+							Messages.getString("message.accesscontrol.16"));
+				} else {
+					errMessage = ", " + e.getMessage();
+				}
+				MessageDialog.openError(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.accesscontrol.8") + errMessage);
+
 			}
-			else{
-				// 変更の場合
-				result = new ModifyUserProperty().edit(property);
+		} else{
+			// 変更の場合
+			try {
+				AccessEndpointWrapper.modifyUserInfo(info);
+				result = true;
+
+				// 完了メッセージ
+				MessageDialog.openInformation(
+						null,
+						Messages.getString("successful"),
+						Messages.getString("message.accesscontrol.9"));
+
+			} catch (Exception e) {
+				String errMessage = "";
+				if (e instanceof InvalidRole_Exception) {
+					// 権限なし
+					MessageDialog.openInformation(null, Messages.getString("message"),
+							Messages.getString("message.accesscontrol.16"));
+				} else {
+					errMessage = ", " + e.getMessage();
+				}
+				MessageDialog.openError(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.accesscontrol.10") + errMessage);
+
 			}
 		}
 
@@ -465,6 +564,7 @@ public class UserDialog extends CommonDialog {
 	 */
 	public void setInputData(Property property) {
 		propertySheet.setInput(property);
+		this.update();
 	}
 
 	/**
