@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.composite;
@@ -20,6 +20,8 @@ import java.text.SimpleDateFormat;
 import java.util.Date;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ModifyEvent;
+import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.layout.RowData;
@@ -33,7 +35,9 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.PriorityConstant;
+import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.NumberVerifyListener;
@@ -41,9 +45,9 @@ import com.clustercontrol.composite.PositiveNumberVerifyListener;
 import com.clustercontrol.composite.TimeVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
-import com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
  * 終了遅延タブ用のコンポジットクラスです。
@@ -88,23 +92,23 @@ public class EndDelayComposite extends Composite {
 	protected JobWaitRuleInfo m_waitRule = null;
 	/** シェル */
 	protected Shell m_shell = null;
-	
+
 	/**
 	 * コンストラクタ
 	 * 
-     * @param parent 親コンポジット
-     * @param style スタイル
-     * 
-     * @see org.eclipse.swt.SWT
-     * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
-     * @see #initialize()
+	 * @param parent 親コンポジット
+	 * @param style スタイル
+	 * 
+	 * @see org.eclipse.swt.SWT
+	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
+	 * @see #initialize()
 	 */
 	public EndDelayComposite(Composite parent, int style) {
 		super(parent, style);
 		initialize();
 		m_shell = this.getShell();
 	}
-	
+
 	/**
 	 * コンポジットを配置します。
 	 */
@@ -116,34 +120,37 @@ public class EndDelayComposite extends Composite {
 		layout.marginHeight = 5;
 		layout.fill = true;
 		this.setLayout(layout);
-		
+
 		Composite composite = null;
 		RowLayout rowLayout = null;
 		Label label = null;
-		
+
 		//終了遅延
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		composite.setLayout(rowLayout);
-		
+
 		m_endDelayCondition = new Button(composite, SWT.CHECK);
 		m_endDelayCondition.setText(Messages.getString("end.delay"));
 		m_endDelayCondition.setLayoutData(new RowData(200,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_endDelayCondition.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 
 				//終了遅延コンポジットのオブジェクトの使用不可を設定
 				setEndDelayEnabled(check.getSelection());
+				update();
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
-		
+
 		m_endDelayConditionGroup = new Group(composite, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
@@ -151,7 +158,7 @@ public class EndDelayComposite extends Composite {
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
 		m_endDelayConditionGroup.setLayout(rowLayout);
-		
+
 		//判定対象一覧
 		Group group = new Group(m_endDelayConditionGroup, SWT.NONE);
 		group.setText(Messages.getString("object.list"));
@@ -161,7 +168,7 @@ public class EndDelayComposite extends Composite {
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
 		group.setLayout(rowLayout);
-		
+
 		//セッション開始後の時間
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -173,6 +180,7 @@ public class EndDelayComposite extends Composite {
 		m_sessionCondition.setLayoutData(new RowData(180,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_sessionCondition.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
@@ -180,10 +188,12 @@ public class EndDelayComposite extends Composite {
 				} else {
 					m_sessionValue.setEnabled(false);
 				}
+				update();
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
 		//セッション開始後の時間の値
@@ -192,7 +202,15 @@ public class EndDelayComposite extends Composite {
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_sessionValue.addVerifyListener(
 				new PositiveNumberVerifyListener(0, DataRangeConstant.SMALLINT_HIGH));
-		
+		m_sessionValue.addModifyListener(
+				new ModifyListener(){
+					@Override
+					public void modifyText(ModifyEvent arg0) {
+						update();
+					}
+				}
+		);
+
 		//ジョブ開始後の時間
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -204,6 +222,7 @@ public class EndDelayComposite extends Composite {
 		m_jobCondition.setLayoutData(new RowData(180,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_jobCondition.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
@@ -211,10 +230,12 @@ public class EndDelayComposite extends Composite {
 				} else {
 					m_jobValue.setEnabled(false);
 				}
+				update();
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
 		//ジョブ開始後の時間の値
@@ -223,7 +244,15 @@ public class EndDelayComposite extends Composite {
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_jobValue.addVerifyListener(
 				new PositiveNumberVerifyListener(0, DataRangeConstant.SMALLINT_HIGH));
-		
+		m_jobValue.addModifyListener(
+				new ModifyListener(){
+					@Override
+					public void modifyText(ModifyEvent arg0) {
+						update();
+					}
+				}
+		);
+
 		//時刻
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -235,6 +264,7 @@ public class EndDelayComposite extends Composite {
 		m_timeCondition.setLayoutData(new RowData(180,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_timeCondition.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
@@ -242,10 +272,12 @@ public class EndDelayComposite extends Composite {
 				} else {
 					m_timeValue.setEnabled(false);
 				}
+				update();
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
 		//時刻の値
@@ -253,7 +285,15 @@ public class EndDelayComposite extends Composite {
 		m_timeValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_timeValue.addVerifyListener(new TimeVerifyListener());
-		
+		m_timeValue.addModifyListener(
+				new ModifyListener(){
+					@Override
+					public void modifyText(ModifyEvent arg0) {
+						update();
+					}
+				}
+		);
+
 		//判定対象の条件関係
 		group = new Group(m_endDelayConditionGroup, SWT.NONE);
 		group.setText(Messages.getString("condition.between.objects"));
@@ -263,7 +303,7 @@ public class EndDelayComposite extends Composite {
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
 		group.setLayout(rowLayout);
-		
+
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -279,7 +319,7 @@ public class EndDelayComposite extends Composite {
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		label = new Label(composite, SWT.NONE);
 		label.setLayoutData(new RowData(77, SizeConstant.SIZE_LABEL_HEIGHT));
-		
+
 		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -287,7 +327,7 @@ public class EndDelayComposite extends Composite {
 		composite.setLayout(rowLayout);
 		label = new Label(composite, SWT.NONE);
 		label.setLayoutData(new RowData(5, SizeConstant.SIZE_LABEL_HEIGHT));
-		
+
 		//通知
 		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -299,6 +339,7 @@ public class EndDelayComposite extends Composite {
 		m_notifyCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_notifyCondition.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
@@ -307,9 +348,10 @@ public class EndDelayComposite extends Composite {
 					m_notifyPriority.setEnabled(false);
 				}
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
 		//通知の重要度
@@ -320,7 +362,7 @@ public class EndDelayComposite extends Composite {
 		m_notifyPriority.add(PriorityConstant.STRING_WARNING);
 		m_notifyPriority.add(PriorityConstant.STRING_CRITICAL);
 		m_notifyPriority.add(PriorityConstant.STRING_UNKNOWN);
-		
+
 		//操作
 		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -332,11 +374,12 @@ public class EndDelayComposite extends Composite {
 		m_operationCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_operationCondition.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
 					m_operationType.setEnabled(true);
-					
+
 					int type = getSelectOperationName(m_operationType);
 					if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
 						m_operationValue.setEnabled(false);
@@ -351,13 +394,15 @@ public class EndDelayComposite extends Composite {
 					m_operationValue.setEnabled(false);
 					m_operationConditionGroup.setEnabled(false);
 				}
+				update();
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
-		
+
 		m_operationConditionGroup = new Group(m_endDelayConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
@@ -365,7 +410,7 @@ public class EndDelayComposite extends Composite {
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
 		m_operationConditionGroup.setLayout(rowLayout);
-		
+
 		//操作の名前
 		composite = new Composite(m_operationConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -383,9 +428,10 @@ public class EndDelayComposite extends Composite {
 		m_operationType.add(OperationConstant.STRING_STOP_SUSPEND);
 		m_operationType.add(OperationConstant.STRING_STOP_SET_END_VALUE);
 		m_operationType.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Combo check = (Combo) e.getSource();
-				
+
 				int type = getSelectOperationName(check);
 				if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
 					m_operationValue.setEnabled(false);
@@ -394,13 +440,15 @@ public class EndDelayComposite extends Composite {
 				} else if(type == OperationConstant.TYPE_STOP_SET_END_VALUE){
 					m_operationValue.setEnabled(true);
 				}
+				update();
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
-		
+
 		//操作の終了値
 		composite = new Composite(m_operationConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -416,10 +464,49 @@ public class EndDelayComposite extends Composite {
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_operationValue.addVerifyListener(
 				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
+		m_operationValue.addModifyListener(
+				new ModifyListener(){
+					@Override
+					public void modifyText(ModifyEvent arg0) {
+						update();
+					}
+				}
+		);
+
 		label = new Label(composite, SWT.NONE);
 		label.setLayoutData(new RowData(70, SizeConstant.SIZE_LABEL_HEIGHT));
 	}
-	
+
+	@Override
+	public void update() {
+		// 必須項目を明示
+		if(m_endDelayCondition.getSelection() && m_sessionCondition.getSelection() &&
+				"".equals(this.m_sessionValue.getText())){
+			this.m_sessionValue.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_sessionValue.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if(m_endDelayCondition.getSelection() && m_jobCondition.getSelection() &&
+				"".equals(this.m_jobValue.getText())){
+			this.m_jobValue.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_jobValue.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if(m_endDelayCondition.getSelection() && m_timeCondition.getSelection() &&
+				"".equals(this.m_timeValue.getText())){
+			this.m_timeValue.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_timeValue.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if(m_endDelayCondition.getSelection() && m_operationCondition.getSelection() &&
+				getSelectOperationName(m_operationType) == OperationConstant.TYPE_STOP_SET_END_VALUE &&
+				"".equals(this.m_operationValue.getText())){
+			this.m_operationValue.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_operationValue.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+	}
+
 	/**
 	 * ジョブ待ち条件情報をコンポジットに反映します。
 	 * 
@@ -427,78 +514,81 @@ public class EndDelayComposite extends Composite {
 	 */
 	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
-		if (m_waitRule instanceof JobWaitRuleInfo) {
+
+		// 初期値
+		m_endDelayCondition.setSelection(false);
+		m_sessionCondition.setSelection(false);
+		m_sessionValue.setText(String.valueOf(1));
+		m_jobCondition.setSelection(false);
+		m_jobValue.setText(String.valueOf(1));
+		m_timeCondition.setSelection(false);
+		m_andCondition.setSelection(true);
+		m_notifyCondition.setSelection(false);
+		m_notifyPriority.select(0);
+		m_operationCondition.setSelection(false);
+		m_operationType.select(0);
+		m_operationValue.setText(String.valueOf(0));
+
+		if (m_waitRule != null) {
 			//終了遅延
 			m_endDelayCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule
-					.getEnd_delay()));
-			
+					.getEndDelay()));
+
 			//セッション開始後の時間
-			m_sessionCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_session()));
-			
+			m_sessionCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEndDelaySession()));
+
 			//セッション開始後の時間の値
-			m_sessionValue.setText(String.valueOf(m_waitRule.getEnd_delay_session_value()));
-			
+			m_sessionValue.setText(String.valueOf(m_waitRule.getEndDelaySessionValue()));
+
 			//ジョブ開始後の時間
-			m_jobCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_job()));
-			
+			m_jobCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEndDelayJob()));
+
 			//ジョブ開始後の時間の値
-			m_jobValue.setText(String.valueOf(m_waitRule.getEnd_delay_job_value()));
-			
+			m_jobValue.setText(String.valueOf(m_waitRule.getEndDelayJobValue()));
+
 			//時刻
-			m_timeCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_time()));
-			
+			m_timeCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEndDelayTime()));
+
 			//時刻の値
-			if (m_waitRule.getEnd_delay_time_value() instanceof Date) {
+			if (m_waitRule.getEndDelayTimeValue() != null) {
 				SimpleDateFormat formatter = new SimpleDateFormat("HH:mm:ss");
-				m_timeValue.setText(formatter.format(m_waitRule.getEnd_delay_time_value()));
+				m_timeValue.setText(formatter.format(new Date(m_waitRule.getEndDelayTimeValue())));
 			}
 			else{
 				m_timeValue.setText("");
 			}
-			
+
 			//条件関係設定
-			if (m_waitRule.getEnd_delay_condition_type() == ConditionTypeConstant.TYPE_AND) {
+			if (m_waitRule.getEndDelayConditionType() == ConditionTypeConstant.TYPE_AND) {
 				m_andCondition.setSelection(true);
+				m_orCondition.setSelection(false);
 			} else {
+				m_andCondition.setSelection(false);
 				m_orCondition.setSelection(true);
-			}	
-			
+			}
+
 			//通知
-			m_notifyCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_notify()));
-			
+			m_notifyCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEndDelayNotify()));
+
 			//通知の重要度
-			setSelectPriority(m_notifyPriority, 
-					m_waitRule.getEnd_delay_notify_priority());
-			
+			setSelectPriority(m_notifyPriority,
+					m_waitRule.getEndDelayNotifyPriority());
+
 			//操作
-			m_operationCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_operation()));
-			
+			m_operationCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEndDelayOperation()));
+
 			//操作の名前
-			setSelectOperationName(m_operationType, 
-					m_waitRule.getEnd_delay_operation_type());
-			
+			setSelectOperationName(m_operationType,
+					m_waitRule.getEndDelayOperationType());
+
 			//操作の終了値
-			m_operationValue.setText(String.valueOf(m_waitRule.getEnd_delay_operation_end_value()));
-			
-		} else {
-			m_endDelayCondition.setSelection(false);
-			m_sessionCondition.setSelection(false);
-			m_sessionValue.setText(String.valueOf(1));
-			m_jobCondition.setSelection(false);
-			m_jobValue.setText(String.valueOf(1));
-			m_timeCondition.setSelection(false);
-			m_andCondition.setSelection(true);
-			m_notifyCondition.setSelection(false);
-			m_notifyPriority.select(0);
-			m_operationCondition.setSelection(false);
-			m_operationType.select(0);
-			m_operationValue.setText(String.valueOf(0));
+			m_operationValue.setText(String.valueOf(m_waitRule.getEndDelayOperationEndValue()));
 		}
-		
+
 		//終了遅延コンポジットのオブジェクトの使用不可を設定
 		setEndDelayEnabled(m_endDelayCondition.getSelection());
 	}
-	
+
 	/**
 	 * ジョブ待ち条件情報を設定します。
 	 * 
@@ -507,7 +597,7 @@ public class EndDelayComposite extends Composite {
 	public void setWaitRuleInfo(JobWaitRuleInfo start) {
 		m_waitRule = start;
 	}
-	
+
 	/**
 	 * ジョブ待ち条件情報を返します。
 	 * 
@@ -516,7 +606,7 @@ public class EndDelayComposite extends Composite {
 	public JobWaitRuleInfo getWaitRuleInfo() {
 		return m_waitRule;
 	}
-	
+
 	/**
 	 * コンポジットの情報から、ジョブ待ち条件情報を作成する。
 	 * 
@@ -527,25 +617,57 @@ public class EndDelayComposite extends Composite {
 	@SuppressWarnings("unchecked")
 	public ValidateResult createWaitRuleInfo() {
 		ValidateResult result = null;
-		
+
 		//実行内容情報クラスのインスタンスを作成・取得
-		if (m_waitRule == null)
+		if (m_waitRule == null) {
 			m_waitRule = new JobWaitRuleInfo();
-		
+			m_waitRule.setSuspend(YesNoConstant.TYPE_NO);
+			m_waitRule.setSkip(YesNoConstant.TYPE_NO);
+			m_waitRule.setSkipEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setCondition(ConditionTypeConstant.TYPE_AND);
+			m_waitRule.setEndCondition(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setCalendar(YesNoConstant.TYPE_NO);
+			m_waitRule.setCalendarEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setStartDelay(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelaySession(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelaySessionValue(1);
+			m_waitRule.setStartDelayTime(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelayConditionType(ConditionTypeConstant.TYPE_AND);
+			m_waitRule.setStartDelayNotify(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelayOperation(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setEndDelay(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelaySession(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelaySessionValue(1);
+			m_waitRule.setEndDelayJob(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayJobValue(1);
+			m_waitRule.setEndDelayTime(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
+			m_waitRule.setEndDelayNotify(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayOperation(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setSkipEndStatus(0);
+			m_waitRule.setEndStatus(0);
+			m_waitRule.setStartDelayNotifyPriority(0);
+			m_waitRule.setStartDelayOperationType(0);
+			m_waitRule.setEndDelayNotifyPriority(0);
+			m_waitRule.setEndDelayOperationType(0);
+		}
 		//終了遅延
-		m_waitRule.setEnd_delay(YesNoConstant.booleanToType(m_endDelayCondition
+		m_waitRule.setEndDelay(YesNoConstant.booleanToType(m_endDelayCondition
 				.getSelection()));
-		
+
 		//セッション開始後の時間
-		m_waitRule.setEnd_delay_session(YesNoConstant.booleanToType(m_sessionCondition
+		m_waitRule.setEndDelaySession(YesNoConstant.booleanToType(m_sessionCondition
 				.getSelection()));
-		
+
 		//セッション開始後の時間の値
 		try {
-			m_waitRule.setEnd_delay_session_value(
+			m_waitRule.setEndDelaySessionValue(
 					Integer.parseInt(m_sessionValue.getText()));
 		} catch (NumberFormatException e) {
-			if (m_waitRule.getEnd_delay_session() == YesNoConstant.TYPE_YES) {
+			if (m_waitRule.getEndDelaySession() == YesNoConstant.TYPE_YES) {
 				result = new ValidateResult();
 				result.setValid(false);
 				result.setID(Messages.getString("message.hinemos.1"));
@@ -553,17 +675,17 @@ public class EndDelayComposite extends Composite {
 				return result;
 			}
 		}
-		
+
 		//ジョブ開始後の時間
-		m_waitRule.setEnd_delay_job(YesNoConstant.booleanToType(m_jobCondition
+		m_waitRule.setEndDelayJob(YesNoConstant.booleanToType(m_jobCondition
 				.getSelection()));
-		
+
 		//ジョブ開始後の時間の値
 		try {
-			m_waitRule.setEnd_delay_job_value(
+			m_waitRule.setEndDelayJobValue(
 					Integer.parseInt(m_jobValue.getText()));
 		} catch (NumberFormatException e) {
-			if (m_waitRule.getEnd_delay_job() == YesNoConstant.TYPE_YES) {
+			if (m_waitRule.getEndDelayJob() == YesNoConstant.TYPE_YES) {
 				result = new ValidateResult();
 				result.setValid(false);
 				result.setID(Messages.getString("message.hinemos.1"));
@@ -571,34 +693,34 @@ public class EndDelayComposite extends Composite {
 				return result;
 			}
 		}
-		
+
 		//時刻
-		m_waitRule.setEnd_delay_time(YesNoConstant.booleanToType(m_timeCondition
+		m_waitRule.setEndDelayTime(YesNoConstant.booleanToType(m_timeCondition
 				.getSelection()));
-		
+
 		//時刻の値
-		if (m_waitRule.getEnd_delay_time() == YesNoConstant.TYPE_YES) {
-	    	boolean check = false;
-	        SimpleDateFormat formatter = new SimpleDateFormat("HH:mm:ss");
-	        Date from = null;
-	        Date to = null;
-	        Date date = null;
-	        try {
-	        	from = formatter.parse("00:00:00");
-	        	to = formatter.parse("23:59:59");
-	            date = formatter.parse(m_timeValue.getText());
-	            check = true;
-	        } catch (ParseException e) {
-	        	formatter = new SimpleDateFormat("HH:mm");
-		        try {
-		            date = formatter.parse(m_timeValue.getText());
-		            check = true;
-		        } catch (ParseException e1) {
-		        }
-	        }
-	        
-	        if(check){
-	        	//範囲チェック
+		if (m_waitRule.getEndDelayTime() == YesNoConstant.TYPE_YES) {
+			boolean check = false;
+			SimpleDateFormat formatter = new SimpleDateFormat("HH:mm:ss");
+			Date from = null;
+			Date to = null;
+			Date date = null;
+			try {
+				from = formatter.parse("00:00:00");
+				to = formatter.parse("23:59:59");
+				date = formatter.parse(m_timeValue.getText());
+				check = true;
+			} catch (ParseException e) {
+				formatter = new SimpleDateFormat("HH:mm");
+				try {
+					date = formatter.parse(m_timeValue.getText());
+					check = true;
+				} catch (ParseException e1) {
+				}
+			}
+
+			if(check){
+				//範囲チェック
 				if(date.before(from) || date.after(to)){
 					String[] args = { formatter.format(from), formatter.format(to) };
 					result = new ValidateResult();
@@ -608,44 +730,44 @@ public class EndDelayComposite extends Composite {
 					return result;
 				}
 
-				m_waitRule.setEnd_delay_time_value(date);
-	        }
-	        else{
+				m_waitRule.setEndDelayTimeValue(date.getTime());
+			}
+			else{
 				result = new ValidateResult();
 				result.setValid(false);
 				result.setID(Messages.getString("message.hinemos.1"));
 				result.setMessage(Messages.getString("message.hinemos.6"));
 				return result;
-	        }
+			}
 		}
-		
+
 		//条件関係取得
 		if (m_andCondition.getSelection()) {
-			m_waitRule.setEnd_delay_condition_type(ConditionTypeConstant.TYPE_AND);
+			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
 		} else {
-			m_waitRule.setEnd_delay_condition_type(ConditionTypeConstant.TYPE_OR);
+			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_OR);
 		}
-		
+
 		//通知
-		m_waitRule.setEnd_delay_notify(YesNoConstant.booleanToType(m_notifyCondition
+		m_waitRule.setEndDelayNotify(YesNoConstant.booleanToType(m_notifyCondition
 				.getSelection()));
-		
+
 		//通知の重要度
-		m_waitRule.setEnd_delay_notify_priority(getSelectPriority(m_notifyPriority));
-		
+		m_waitRule.setEndDelayNotifyPriority(getSelectPriority(m_notifyPriority));
+
 		//操作
-		m_waitRule.setEnd_delay_operation(YesNoConstant.booleanToType(m_operationCondition
+		m_waitRule.setEndDelayOperation(YesNoConstant.booleanToType(m_operationCondition
 				.getSelection()));
-		
+
 		//操作の名前
-		m_waitRule.setEnd_delay_operation_type(getSelectOperationName(m_operationType));
-		
+		m_waitRule.setEndDelayOperationType(getSelectOperationName(m_operationType));
+
 		//操作の終了値
 		try {
-			m_waitRule.setEnd_delay_operation_end_value(
+			m_waitRule.setEndDelayOperationEndValue(
 					Integer.parseInt(m_operationValue.getText()));
 		} catch (NumberFormatException e) {
-			if (m_waitRule.getEnd_delay_operation() == YesNoConstant.TYPE_YES) {
+			if (m_waitRule.getEndDelayOperation() == YesNoConstant.TYPE_YES) {
 				result = new ValidateResult();
 				result.setValid(false);
 				result.setID(Messages.getString("message.hinemos.1"));
@@ -653,10 +775,10 @@ public class EndDelayComposite extends Composite {
 				return result;
 			}
 		}
-		
+
 		return null;
 	}
-	
+
 	/**
 	 * コンポジットに配置したオブジェクトの使用可・使用不可を設定します。
 	 * 
@@ -665,14 +787,14 @@ public class EndDelayComposite extends Composite {
 	public void setEndDelayEnabled(boolean enabled) {
 		if (enabled) {
 			m_endDelayConditionGroup.setEnabled(true);
-			
+
 			//セッション開始後の時間
 			m_sessionCondition.setEnabled(true);
 			if(m_sessionCondition.getSelection())
 				m_sessionValue.setEnabled(true);
 			else
 				m_sessionValue.setEnabled(false);
-			
+
 			//ジョブ開始後の時間
 			m_jobCondition.setEnabled(true);
 			if(m_jobCondition.getSelection())
@@ -686,25 +808,25 @@ public class EndDelayComposite extends Composite {
 				m_timeValue.setEnabled(true);
 			else
 				m_timeValue.setEnabled(false);
-			
+
 			//判定条件
 			m_andCondition.setEnabled(true);
 			m_orCondition.setEnabled(true);
-			
+
 			//通知
 			m_notifyCondition.setEnabled(true);
 			if(m_notifyCondition.getSelection())
 				m_notifyPriority.setEnabled(true);
 			else
 				m_notifyPriority.setEnabled(false);
-			
+
 			//操作
 			m_operationConditionGroup.setEnabled(true);
 			m_operationCondition.setEnabled(true);
 			if(m_operationCondition.getSelection()){
 				m_operationType.setEnabled(true);
 				m_operationValue.setEnabled(false);
-				
+
 				int type = getSelectOperationName(m_operationType);
 				if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
 					m_operationValue.setEnabled(false);
@@ -720,27 +842,27 @@ public class EndDelayComposite extends Composite {
 			}
 		} else {
 			m_endDelayConditionGroup.setEnabled(false);
-			
+
 			//セッション開始後の時間
 			m_sessionCondition.setEnabled(false);
 			m_sessionValue.setEnabled(false);
-			
+
 			//ジョブ開始後の時間
 			m_jobCondition.setEnabled(false);
 			m_jobValue.setEnabled(false);
-			
+
 			//時刻
 			m_timeCondition.setEnabled(false);
 			m_timeValue.setEnabled(false);
-			
+
 			//判定条件
 			m_andCondition.setEnabled(false);
 			m_orCondition.setEnabled(false);
-			
+
 			//通知
 			m_notifyCondition.setEnabled(false);
 			m_notifyPriority.setEnabled(false);
-			
+
 			//操作
 			m_operationCondition.setEnabled(false);
 			m_operationType.setEnabled(false);
@@ -748,7 +870,7 @@ public class EndDelayComposite extends Composite {
 			m_operationConditionGroup.setEnabled(false);
 		}
 	}
-	
+
 	/**
 	 * 指定した重要度に該当する終了遅延通知重要度用コンボボックスの項目を選択します。
 	 * 
@@ -759,7 +881,7 @@ public class EndDelayComposite extends Composite {
 	 */
 	public void setSelectPriority(Combo combo, int priority) {
 		String select = "";
-		
+
 		if (priority == PriorityConstant.TYPE_CRITICAL) {
 			select = PriorityConstant.STRING_CRITICAL;
 		} else if (priority == PriorityConstant.TYPE_WARNING) {
@@ -771,7 +893,7 @@ public class EndDelayComposite extends Composite {
 		} else if (priority == PriorityConstant.TYPE_NONE) {
 			select = PriorityConstant.STRING_NONE;
 		}
-		
+
 		combo.select(0);
 		for (int i = 0; i < combo.getItemCount(); i++) {
 			if (select.equals(combo.getItem(i))) {
@@ -780,7 +902,7 @@ public class EndDelayComposite extends Composite {
 			}
 		}
 	}
-	
+
 	/**
 	 * 終了遅延通知重要度用コンボボックスにて選択している重要度を取得します。
 	 * 
@@ -791,7 +913,7 @@ public class EndDelayComposite extends Composite {
 	 */
 	public int getSelectPriority(Combo combo) {
 		String select = combo.getText();
-		
+
 		if (select.equals(PriorityConstant.STRING_CRITICAL)) {
 			return PriorityConstant.TYPE_CRITICAL;
 		} else if (select.equals(PriorityConstant.STRING_WARNING)) {
@@ -803,13 +925,13 @@ public class EndDelayComposite extends Composite {
 		} else if (select.equals(PriorityConstant.STRING_NONE)) {
 			return PriorityConstant.TYPE_NONE;
 		}
-		
+
 		return -1;
 	}
-	
+
 	/**
 	 * 指定したジョブ操作種別に該当する終了遅延操作用コンボボックスの項目を選択しまう。
-	 *  
+	 * 
 	 * @param combo コンボボックスのインスタンス
 	 * @param operation ジョブ操作種別
 	 * 
@@ -817,7 +939,7 @@ public class EndDelayComposite extends Composite {
 	 */
 	public void setSelectOperationName(Combo combo, int operation) {
 		String select = "";
-		
+
 		if (operation == OperationConstant.TYPE_STOP_AT_ONCE) {
 			select = OperationConstant.STRING_START_AT_ONCE;
 		} else if (operation == OperationConstant.TYPE_STOP_SUSPEND) {
@@ -825,7 +947,7 @@ public class EndDelayComposite extends Composite {
 		} else if (operation == OperationConstant.TYPE_STOP_SET_END_VALUE) {
 			select = OperationConstant.STRING_STOP_SET_END_VALUE;
 		}
-		
+
 		combo.select(0);
 		for (int i = 0; i < combo.getItemCount(); i++) {
 			if (select.equals(combo.getItem(i))) {
@@ -834,7 +956,7 @@ public class EndDelayComposite extends Composite {
 			}
 		}
 	}
-	
+
 	/**
 	 * 終了遅延操作用コンボボックスにて選択しているジョブ操作種別を取得します。
 	 * 
@@ -845,7 +967,7 @@ public class EndDelayComposite extends Composite {
 	 */
 	public int getSelectOperationName(Combo combo) {
 		String select = combo.getText();
-		
+
 		if (select.equals(OperationConstant.STRING_STOP_AT_ONCE)) {
 			return OperationConstant.TYPE_STOP_AT_ONCE;
 		} else if (select.equals(OperationConstant.STRING_STOP_SUSPEND)) {
@@ -853,7 +975,7 @@ public class EndDelayComposite extends Composite {
 		} else if (select.equals(OperationConstant.STRING_STOP_SET_END_VALUE)) {
 			return OperationConstant.TYPE_STOP_SET_END_VALUE;
 		}
-		
+
 		return -1;
 	}
 }
\ No newline at end of file
