@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.composite;
@@ -19,10 +19,13 @@ import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.List;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ModifyEvent;
+import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -38,7 +41,7 @@ import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.EndStatusConstant;
-import com.clustercontrol.bean.JudgmentObjectConstant;
+import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.CommonTableViewer;
@@ -46,12 +49,13 @@ import com.clustercontrol.composite.NumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.action.GetWaitRuleTableDefine;
 import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
-import com.clustercontrol.jobmanagement.bean.JobObjectInfo;
-import com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo;
-import com.clustercontrol.jobmanagement.bean.WaitRuleTableDefine;
+import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
 import com.clustercontrol.jobmanagement.composite.action.WaitRuleSelectionChangedListener;
 import com.clustercontrol.jobmanagement.dialog.WaitRuleDialog;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.ws.jobmanagement.JobObjectInfo;
+import com.clustercontrol.ws.jobmanagement.JobTreeItem;
+import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
  * 待ち条件タブ用のコンポジットクラスです。
@@ -84,29 +88,25 @@ public class WaitRuleComposite extends Composite {
 	protected Shell m_shell = null;
 	/** 選択アイテム */
 	protected ArrayList m_selectItem = null;
-	/** 親ジョブID */
-	protected String m_parentJobId = null;
-	/** ジョブID */
-	protected String m_jobId = null;
-	/** ジョブユニットのジョブID **/
-	protected String m_jobunitId = null;
-	
+
+	private JobTreeItem m_jobTreeItem = null;
+
 	/**
 	 * コンストラクタ
 	 * 
-     * @param parent 親のコンポジット
-     * @param style スタイル
-     * 
-     * @see org.eclipse.swt.SWT
-     * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
-     * @see #initialize()
+	 * @param parent 親のコンポジット
+	 * @param style スタイル
+	 * 
+	 * @see org.eclipse.swt.SWT
+	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
+	 * @see #initialize()
 	 */
 	public WaitRuleComposite(Composite parent, int style) {
 		super(parent, style);
 		initialize();
 		m_shell = this.getShell();
 	}
-	
+
 	/**
 	 * コンポジットを構築します。
 	 */
@@ -118,30 +118,30 @@ public class WaitRuleComposite extends Composite {
 		layout.marginHeight = 5;
 		layout.fill = true;
 		this.setLayout(layout);
-		
+
 		Composite composite = null;
 		RowLayout rowLayout = null;
-		
+
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		composite.setLayout(rowLayout);
-		
+
 		Label tableTitle = new Label(composite, SWT.NONE);
 		tableTitle.setText(Messages.getString("object.list"));
-		
+
 		Table table = new Table(composite, SWT.BORDER | SWT.H_SCROLL
 				| SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.SINGLE);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
 		table.setLayoutData(new RowData(430, 80));
-		
+
 		composite = new Composite(composite, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 5;
 		composite.setLayout(rowLayout);
-		
+
 		//判定対象の追加
 		Label dummy1 = new Label(composite, SWT.NONE);
 		dummy1.setLayoutData(new RowData(190, SizeConstant.SIZE_LABEL_HEIGHT));
@@ -153,45 +153,45 @@ public class WaitRuleComposite extends Composite {
 			@Override
 			@SuppressWarnings("unchecked")
 			public void widgetSelected(SelectionEvent e) {
-				WaitRuleDialog dialog = new WaitRuleDialog(m_shell, m_parentJobId, m_jobId, m_jobunitId);
+				WaitRuleDialog dialog = new WaitRuleDialog(m_shell, m_jobTreeItem);
 				if (dialog.open() == IDialogConstants.OK_ID) {
-					
+
 					// 待ち条件を追加するかどうかを示すフラグ
 					boolean addWaitRule = true;
-					
+
 					ArrayList info = dialog.getInputData();
 					ArrayList list = (ArrayList) m_viewer.getInput();
 					if (list == null) {
 						list = new ArrayList();
-						
+
 					} else {
-						
+
 						//待ち条件として複数の時刻を設定しようとした場合はフラグをfalseとする
-						int newWaitRuleType = (Integer) info.get(WaitRuleTableDefine.JUDGMENT_OBJECT);
+						int newWaitRuleType = (Integer) info.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
 						if (newWaitRuleType == JudgmentObjectConstant.TYPE_TIME){
-							
+
 							Iterator itr = list.iterator();
 							while (itr.hasNext()) {
 								ArrayList waitRule = (ArrayList) itr.next();
-								int rule = (Integer) waitRule.get(WaitRuleTableDefine.JUDGMENT_OBJECT);
+								int rule = (Integer) waitRule.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
 								if (rule == JudgmentObjectConstant.TYPE_TIME) {
 									addWaitRule = false;
-									
-		            				MessageDialog.openWarning(
-		            						null, 
-		            						Messages.getString("warning"), 
-		            						Messages.getString("message.job.61"));
+
+									MessageDialog.openWarning(
+											null,
+											Messages.getString("warning"),
+											Messages.getString("message.job.61"));
 								}
 							}
 						}
 					}
-					
+
 					if (addWaitRule) list.add(info);
 					m_viewer.setInput(list);
 				}
 			}
 		});
-		
+
 		//判定対象の変更
 		m_modifyCondition = new Button(composite, SWT.NONE);
 		m_modifyCondition.setText(Messages.getString("modify"));
@@ -201,26 +201,26 @@ public class WaitRuleComposite extends Composite {
 			@Override
 			@SuppressWarnings("unchecked")
 			public void widgetSelected(SelectionEvent e) {
-				WaitRuleDialog dialog = new WaitRuleDialog(m_shell, m_parentJobId, m_jobId, m_jobunitId);
+				WaitRuleDialog dialog = new WaitRuleDialog(m_shell, m_jobTreeItem);
 				if (m_selectItem instanceof ArrayList) {
 					dialog.setInputData(m_selectItem);
 					if (dialog.open() == IDialogConstants.OK_ID) {
-						
+
 						ArrayList info = dialog.getInputData();
 						ArrayList list = (ArrayList) m_viewer.getInput();
 
 						list.remove(m_selectItem);
 						list.add(info);
-						
+
 						m_selectItem = null;
 						m_viewer.setInput(list);
 					}
 				} else {
-					
+
 				}
 			}
 		});
-		
+
 		//判定対象の削除
 		m_deleteCondition = new Button(composite, SWT.NONE);
 		m_deleteCondition.setText(Messages.getString("delete"));
@@ -235,11 +235,11 @@ public class WaitRuleComposite extends Composite {
 					m_selectItem = null;
 					m_viewer.setInput(list);
 				} else {
-					
+
 				}
 			}
 		});
-		
+
 		//判定対象の条件関係
 		Group group = new Group(this, SWT.NONE);
 		group.setText(Messages.getString("condition.between.objects"));
@@ -249,7 +249,7 @@ public class WaitRuleComposite extends Composite {
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
 		group.setLayout(rowLayout);
-		
+
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -263,12 +263,12 @@ public class WaitRuleComposite extends Composite {
 		m_orCondition.setText(Messages.getString("or"));
 		m_orCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		
+
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		composite.setLayout(rowLayout);
-		
+
 		//条件を満たさないときに終了
 		Label dummy2 = new Label(composite, SWT.NONE);
 		dummy2.setLayoutData(new RowData(190, SizeConstant.SIZE_LABEL_HEIGHT));
@@ -278,6 +278,7 @@ public class WaitRuleComposite extends Composite {
 		m_endCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_endCondition.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
@@ -287,13 +288,15 @@ public class WaitRuleComposite extends Composite {
 					m_endConditionGroup.setEnabled(false);
 					m_endValue.setEnabled(false);
 				}
+				update();
 			}
-			
+
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
-				
+
 			}
 		});
-		
+
 		m_endConditionGroup = new Group(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
@@ -301,7 +304,7 @@ public class WaitRuleComposite extends Composite {
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
 		m_endConditionGroup.setLayout(rowLayout);
-		
+
 		composite = new Composite(m_endConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -316,16 +319,33 @@ public class WaitRuleComposite extends Composite {
 		.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
 		m_endValue.addVerifyListener(
 				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
-		
+		m_endValue.addModifyListener(
+				new ModifyListener(){
+					@Override
+					public void modifyText(ModifyEvent arg0) {
+						update();
+					}
+				}
+		);
+
 		m_viewer = new CommonTableViewer(table);
 		m_viewer.createTableColumn(GetWaitRuleTableDefine.get(),
-				WaitRuleTableDefine.SORT_COLUMN_INDEX,
-				WaitRuleTableDefine.SORT_ORDER);
+				GetWaitRuleTableDefine.SORT_COLUMN_INDEX,
+				GetWaitRuleTableDefine.SORT_ORDER);
 		m_viewer
 		.addSelectionChangedListener(new WaitRuleSelectionChangedListener(
 				this));
 	}
-	
+
+	@Override
+	public void update() {
+		if(m_endCondition.getSelection() && "".equals(this.m_endValue.getText())){
+			this.m_endValue.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_endValue.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+	}
+
 	/**
 	 * ジョブ待ち条件情報をコンポジットに反映します。
 	 * 
@@ -333,16 +353,23 @@ public class WaitRuleComposite extends Composite {
 	 */
 	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
-		if (m_waitRule instanceof JobWaitRuleInfo) {
+
+		// 初期値
+		m_andCondition.setSelection(true);
+		m_endCondition.setSelection(false);
+		m_endValue.setText(String
+				.valueOf(EndStatusConstant.INITIAL_VALUE_NORMAL));
+
+		if (m_waitRule != null) {
 			//判定対象と開始条件値設定
-			ArrayList list = m_waitRule.getObject();
+			List<JobObjectInfo> list = m_waitRule.getObject();
 			if(list != null){
 				ArrayList tableData = new ArrayList();
 				for (int i = 0; i < list.size(); i++) {
-					JobObjectInfo info = (JobObjectInfo) list.get(i);
+					JobObjectInfo info = list.get(i);
 					ArrayList tableLineData = new ArrayList();
 					tableLineData.add(new Integer(info.getType()));
-					if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STAUS) {
+					if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
 						tableLineData.add(info.getJobId());
 						tableLineData.add(EndStatusConstant.typeToString(info.getValue()));
 					}
@@ -352,33 +379,34 @@ public class WaitRuleComposite extends Composite {
 					}
 					else {
 						tableLineData.add("");
-						tableLineData.add(info.getTime());
+						if (info.getTime() != null) {
+							tableLineData.add(new Date(info.getTime()));
+						} else {
+							tableLineData.add("");
+						}
 					}
 					tableData.add(tableLineData);
 				}
 				m_viewer.setInput(tableData);
 			}
-			
+
 			//条件関係設定
 			if (m_waitRule.getCondition() == ConditionTypeConstant.TYPE_AND) {
 				m_andCondition.setSelection(true);
+				m_orCondition.setSelection(false);
 			} else {
+				m_andCondition.setSelection(false);
 				m_orCondition.setSelection(true);
 			}
-			
+
 			//開始条件を満たさないとき終了 設定
 			m_endCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule
 					.getEndCondition()));
-			
+
 			//終了値
 			m_endValue.setText(String.valueOf(m_waitRule.getEndValue()));
-		} else {
-			m_andCondition.setSelection(true);
-			m_endCondition.setSelection(false);
-			m_endValue.setText(String
-					.valueOf(EndStatusConstant.INITIAL_VALUE_NORMAL));
 		}
-		
+
 		//開始条件を満たさないとき終了
 		if (m_endCondition.getSelection()) {
 			m_endConditionGroup.setEnabled(true);
@@ -388,7 +416,7 @@ public class WaitRuleComposite extends Composite {
 			m_endValue.setEnabled(false);
 		}
 	}
-	
+
 	/**
 	 * ジョブ待ち条件情報を設定します。
 	 * 
@@ -397,7 +425,7 @@ public class WaitRuleComposite extends Composite {
 	public void setWaitRuleInfo(JobWaitRuleInfo start) {
 		m_waitRule = start;
 	}
-	
+
 	/**
 	 * ジョブ待ち条件情報を返します。
 	 * 
@@ -406,7 +434,35 @@ public class WaitRuleComposite extends Composite {
 	public JobWaitRuleInfo getWaitRuleInfo() {
 		return m_waitRule;
 	}
-	
+
+	public static JobObjectInfo array2JobObjectInfo(ArrayList tableLineData) {
+		Integer type = (Integer) tableLineData
+		.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
+		JobObjectInfo info = new JobObjectInfo();
+		info.setValue(0);
+		info.setType(type.intValue());
+		if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
+			info.setJobId((String) tableLineData
+					.get(GetWaitRuleTableDefine.JOB_ID));
+			String value = (String) tableLineData
+			.get(GetWaitRuleTableDefine.START_VALUE);
+			info.setValue(EndStatusConstant.stringToType(value));
+		}
+		else if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
+			info.setJobId((String) tableLineData
+					.get(GetWaitRuleTableDefine.JOB_ID));
+			Integer value = (Integer) tableLineData
+			.get(GetWaitRuleTableDefine.START_VALUE);
+			info.setValue(value.intValue());
+		}
+		else {
+			Date value = (Date) tableLineData
+			.get(GetWaitRuleTableDefine.START_VALUE);
+			info.setTime(value.getTime());
+		}
+		return info;
+	}
+
 	/**
 	 * コンポジットの情報から、ジョブ待ち条件情報を作成します。
 	 * 
@@ -417,31 +473,54 @@ public class WaitRuleComposite extends Composite {
 	@SuppressWarnings("unchecked")
 	public ValidateResult createWaitRuleInfo() {
 		ValidateResult result = null;
-		
+
 		//実行内容情報クラスのインスタンスを作成・取得
-		if (m_waitRule == null)
+		if (m_waitRule == null) {
 			m_waitRule = new JobWaitRuleInfo();
-		
+			m_waitRule.setSuspend(YesNoConstant.TYPE_NO);
+			m_waitRule.setSkip(YesNoConstant.TYPE_NO);
+			m_waitRule.setSkipEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setCondition(ConditionTypeConstant.TYPE_AND);
+			m_waitRule.setEndCondition(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setCalendar(YesNoConstant.TYPE_NO);
+			m_waitRule.setCalendarEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setStartDelay(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelaySession(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelaySessionValue(1);
+			m_waitRule.setStartDelayTime(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelayConditionType(ConditionTypeConstant.TYPE_AND);
+			m_waitRule.setStartDelayNotify(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelayOperation(YesNoConstant.TYPE_NO);
+			m_waitRule.setStartDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setEndDelay(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelaySession(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelaySessionValue(1);
+			m_waitRule.setEndDelayJob(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayJobValue(1);
+			m_waitRule.setEndDelayTime(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
+			m_waitRule.setEndDelayNotify(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayOperation(YesNoConstant.TYPE_NO);
+			m_waitRule.setEndDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
+			m_waitRule.setSkipEndStatus(0);
+			m_waitRule.setEndStatus(0);
+			m_waitRule.setStartDelayNotifyPriority(0);
+			m_waitRule.setStartDelayOperationType(0);
+			m_waitRule.setEndDelayNotifyPriority(0);
+			m_waitRule.setEndDelayOperationType(0);
+		}
 		//判定対象と開始条件値取得
-		ArrayList list = new ArrayList();
+		ArrayList<JobObjectInfo> list = new ArrayList<JobObjectInfo>();
 		ArrayList tableData = (ArrayList) m_viewer.getInput();
-		HashMap map = new HashMap();
+		HashMap<String, Integer> map = new HashMap<String, Integer>();
 		if (tableData instanceof ArrayList) {
 			for (int i = 0; i < tableData.size(); i++) {
 				ArrayList tableLineData = (ArrayList) tableData.get(i);
-				JobObjectInfo info = new JobObjectInfo();
-				Integer type = (Integer) tableLineData
-				.get(WaitRuleTableDefine.JUDGMENT_OBJECT);
-				info.setType(type.intValue());
-				if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STAUS) {
-					info.setJobId((String) tableLineData
-							.get(WaitRuleTableDefine.JOB_ID));
-					String value = (String) tableLineData
-					.get(WaitRuleTableDefine.START_VALUE);
-					info.setValue(EndStatusConstant.stringToType(value));
-					
-					//重複チェック
-					Integer checkValue = (Integer) map.get(info.getJobId() + info.getType());
+				JobObjectInfo info = array2JobObjectInfo(tableLineData);
+				// 重複チェックをしてから、リストに追加する。
+				if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
+					Integer checkValue = map.get(info.getJobId() + info.getType());
 					if (checkValue == null
 							|| checkValue.intValue() != info.getValue()) {
 						list.add(info);
@@ -449,14 +528,7 @@ public class WaitRuleComposite extends Composite {
 					}
 				}
 				else if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
-					info.setJobId((String) tableLineData
-							.get(WaitRuleTableDefine.JOB_ID));
-					Integer value = (Integer) tableLineData
-					.get(WaitRuleTableDefine.START_VALUE);
-					info.setValue(value.intValue());
-					
-					//重複チェック
-					Integer checkValue = (Integer) map.get(info.getJobId() + info.getType());
+					Integer checkValue = map.get(info.getJobId() + info.getType());
 					if (checkValue == null
 							|| checkValue.intValue() != info.getValue()) {
 						list.add(info);
@@ -464,31 +536,28 @@ public class WaitRuleComposite extends Composite {
 					}
 				}
 				else {
-					Date value = (Date) tableLineData
-					.get(WaitRuleTableDefine.START_VALUE);
-					info.setTime(value);
-					
-					//重複チェック
 					if (map.get("TIME") == null) {
 						list.add(info);
-						map.put("TIME", "1");
+						map.put("TIME", 1);
 					}
 				}
 			}
 		}
-		m_waitRule.setObject(list);
-		
+		List<JobObjectInfo> jobObjectInfoList = m_waitRule.getObject();
+		jobObjectInfoList.clear();
+		jobObjectInfoList.addAll(list);
+
 		//条件関係取得
 		if (m_andCondition.getSelection()) {
 			m_waitRule.setCondition(ConditionTypeConstant.TYPE_AND);
 		} else {
 			m_waitRule.setCondition(ConditionTypeConstant.TYPE_OR);
 		}
-		
+
 		//開始条件を満たさないとき終了 設定
 		m_waitRule.setEndCondition(YesNoConstant.booleanToType(m_endCondition
 				.getSelection()));
-		
+
 		//終了値取得
 		try {
 			m_waitRule.setEndValue(Integer.parseInt(m_endValue.getText()));
@@ -501,10 +570,10 @@ public class WaitRuleComposite extends Composite {
 				return result;
 			}
 		}
-		
+
 		return null;
 	}
-	
+
 	/**
 	 * 選択アイテムを返します。
 	 * 
@@ -513,7 +582,7 @@ public class WaitRuleComposite extends Composite {
 	public ArrayList getSelectItem() {
 		return m_selectItem;
 	}
-	
+
 	/**
 	 * 選択アイテムを設定します。
 	 * 
@@ -522,60 +591,13 @@ public class WaitRuleComposite extends Composite {
 	public void setSelectItem(ArrayList selectItem) {
 		m_selectItem = selectItem;
 	}
-	
-	/**
-	 * 親ジョブIDを返します。
-	 * 
-	 * @return 親ジョブID
-	 */
-	public String getParentJobId() {
-		return m_parentJobId;
+
+	public JobTreeItem getJobTreeItem() {
+		return m_jobTreeItem;
 	}
-	
-	/**
-	 * 親ジョブIDを設定します。
-	 * 
-	 * @param parentJobId 親ジョブID
-	 */
-	public void setParentJobId(String parentJobId) {
-		m_parentJobId = parentJobId;
+
+	public void setJobTreeItem(JobTreeItem jobTreeItem) {
+		m_jobTreeItem = jobTreeItem;
 	}
-	
-	/**
-	 * ジョブIDを返します。
-	 * 
-	 * @return ジョブID
-	 */
-	public String getJobId() {
-		return m_jobId;
-	}
-	
-	/**
-	 * ジョブIDを設定します。
-	 * 
-	 * @param jobId ジョブID
-	 */
-	public void setJobId(String jobId) {
-		m_jobId = jobId;
-	}
-	
-	/**
-	 * ジョブユニットのジョブIDを返します。
-	 * 
-	 * @return ジョブユニットのジョブID
-	 */
-	public String getJobunitId() {
-		return m_jobunitId;
-	}
-	
-	/**
-	 * ジョブユニットのジョブIDを設定します。
-	 * 
-	 * @param jobunitId ジョブユニットのジョブID
-	 */
-	public void setJobunitId(String jobunitId) {
-		m_jobunitId = jobunitId;
-	}
-	
-	
+
 }
\ No newline at end of file
