@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.dao;
@@ -49,40 +49,42 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobInfoPK;
  * @see com.clustercontrol.jobmanagement.dao.JobInfoDAO
  */
 public class JobInfoDAOImpl implements JobInfoDAO {
-	
-	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog(JobInfoDAOImpl.class);
 
+	/** ログ出力のインスタンス。 */
+	private static Log m_log = LogFactory.getLog(JobInfoDAOImpl.class);
+
+	@Override
 	public void init() {
 	}
-	
-	/** 
+
+	/**
 	 * SELECT文を発行します。
 	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobInfoBean)
 	 */
+	@Override
 	public void load(JobInfoPK pk, JobInfoBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				//取得した値をBeanにセット
 				ejb.setDescription(res.getString("description"));
@@ -90,20 +92,20 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 				ejb.setJobunit_id(res.getString("jobunit_id"));
 				ejb.setJob_name(res.getString("job_name"));
 				ejb.setJob_type(res.getInt("job_type"));
-				
+
 				if(res.getTimestamp("reg_date") != null)
 					ejb.setReg_date(new Date(res.getTimestamp("reg_date").getTime()));
 				else
 					ejb.setReg_date(null);
-				
+
 				ejb.setReg_user(res.getString("reg_user"));
 				ejb.setSession_id(res.getString("session_id"));
-				
+
 				if(res.getTimestamp("update_date") != null)
 					ejb.setUpdate_date(new Date(res.getTimestamp("update_date").getTime()));
 				else
 					ejb.setUpdate_date(null);
-				
+
 				ejb.setUpdate_user(res.getString("update_user"));
 			} else {
 				String msg = "JobInfo data is not found.";
@@ -132,21 +134,22 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 		}
 		m_log.debug("load() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * UPDATE文を発行します。
 	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobInfoBean)
 	 */
+	@Override
 	public void store(JobInfoBean ejb) throws EJBException {
 		m_log.debug("store() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
@@ -162,18 +165,18 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 			sql.append("WHERE session_id = ? AND ");
 			sql.append("job_id = ?");
 			sql.append("jobunit_id = ?");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getJob_name());
 			stmt.setString(2, ejb.getDescription());
 			stmt.setInt(3, ejb.getJob_type());
-			if(ejb.getReg_date() instanceof java.util.Date)
+			if(ejb.getReg_date() != null)
 				stmt.setTimestamp(4, new Timestamp(ejb.getReg_date().getTime()));
 			else
 				stmt.setTimestamp(4, null);
-			if(ejb.getUpdate_date() instanceof java.util.Date)
+			if(ejb.getUpdate_date() != null)
 				stmt.setTimestamp(5, new Timestamp(ejb.getUpdate_date().getTime()));
 			else
 				stmt.setTimestamp(5, null);
@@ -182,20 +185,20 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 			stmt.setString(8, ejb.getSession_id());
 			stmt.setString(9, ejb.getJob_id());
 			stmt.setString(10, ejb.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+					+ ", jobunitId=" + ejb.getJobunit_id()
+					+ ", jobId=" + ejb.getJob_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクローズ
@@ -208,8 +211,8 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -217,41 +220,42 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
 	}
-	
+
 	/**
 	 * DELETE文を発行します。
 	 * 引数で指定されたプライマリキーでデータベースから削除します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobInfoPK)
 	 */
+	@Override
 	public void remove(JobInfoPK pk) throws RemoveException, EJBException {
 		m_log.debug("remove() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "DELETE FROM cc_job_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1 ) {
 				String msg = "result row is not 1";
 				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
-				throw new EJBException(msg);	
+				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
-			
+
 		} finally {
 			try {
 				if(stmt != null){
@@ -267,18 +271,19 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 		}
 		m_log.debug("remove() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * INSERT文を発行します。
 	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobInfoBean)
 	 */
+	@Override
 	public JobInfoPK create(JobInfoBean ejb) throws CreateException, EJBException {
 		m_log.debug("create() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		JobInfoPK pk;
@@ -298,45 +303,45 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 			sql.append("update_user, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getSession_id());
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setString(3, ejb.getJob_name());
 			stmt.setString(4, ejb.getDescription());
 			stmt.setInt(5, ejb.getJob_type());
-			if(ejb.getReg_date() instanceof java.util.Date)
+			if(ejb.getReg_date() != null)
 				stmt.setTimestamp(6, new Timestamp(ejb.getReg_date().getTime()));
 			else
 				stmt.setTimestamp(6, null);
-			if(ejb.getUpdate_date() instanceof java.util.Date)
+			if(ejb.getUpdate_date() != null)
 				stmt.setTimestamp(7, new Timestamp(ejb.getUpdate_date().getTime()));
 			else
 				stmt.setTimestamp(7, null);
 			stmt.setString(8, ejb.getReg_user());
 			stmt.setString(9, ejb.getUpdate_user());
 			stmt.setString(10, ejb.getJobunit_id());
-			
+
 			int row =	stmt.executeUpdate();
 			pk = new JobInfoPK(
 					ejb.getSession_id(),
 					ejb.getJobunit_id(),
 					ejb.getJob_id());
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -350,8 +355,8 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -360,7 +365,7 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 				+ ", jobId=" + ejb.getJob_id());
 		return pk;
 	}
-	
+
 	/**
 	 * 全件取得するSELECT文を発行します。
 	 * 取得したデータのプライマリキーをコレクションに格納し返します。
@@ -368,22 +373,23 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobInfoDAO#findAll()
 	 */
+	@Override
 	public Collection findAll() throws FinderException {
 		m_log.debug("findAll() start : ");
-		
+
 		ArrayList<JobInfoPK> ret = new ArrayList<JobInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobInfoPK pk= new JobInfoPK(
 						res.getString("session_id"),
@@ -392,7 +398,7 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
@@ -413,7 +419,7 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 		m_log.debug("findAll() end : ");
 		return ret;
 	}
-	
+
 	/**
 	 * 1件取得するSELECT文を発行します。
 	 * 引数で指定されたプライマリキーで、データベースを検索します。
@@ -421,26 +427,27 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobInfoPK)
 	 */
+	@Override
 	public JobInfoPK findByPrimaryKey(JobInfoPK pk) throws FinderException {
 		m_log.debug("findByPrimaryKey() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				return pk;
 			} else {
@@ -466,7 +473,7 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
 		}
 	}
-	
+
 	/**
 	 * ジョブ情報をジョブマスタから作成します。
 	 * 
@@ -479,17 +486,17 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 	public void makeSession(String sessionId, String jobunitId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : sessionId=" + sessionId
 				+ ", jobunitId=" + jobunitId);
-		
+
 		Connection conn = null;
 		Connection connMaster = null;
 		PreparedStatement stmt = null;
 		PreparedStatement stmtMaster = null;
 		String jobId = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_info (");
@@ -508,27 +515,27 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1, sessionId);
-			
+
 			//SQL文の定義(マスタ検索)
 			StringBuilder sqlMaster = new StringBuilder();
 			sqlMaster.append("SELECT * FROM cc_job_mst ");
 			sqlMaster.append("WHERE cc_job_mst.job_id = ?");
 			sqlMaster.append("AND cc_job_mst.jobunit_id = ?");
-			
+
 			//SQL文のセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sqlMaster.toString());
 			stmtMaster.setString(2, jobunitId);
-			
+
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
 				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
-				
+
 				//SQL実行(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				ResultSet resMaster = stmtMaster.executeQuery();
-				
+
 				if (resMaster.next()) {
 					//ジョブの場合、INSERTを実行
 					stmt.setString(2, resMaster.getString("job_id"));
@@ -556,8 +563,8 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("makeSession() error : sessionId="
-								+ sessionId + ", jobunitId=" + jobunitId
-								+ ", jobId=" + jobId + " SQLException" + "DuplicateKeyException ");
+						+ sessionId + ", jobunitId=" + jobunitId
+						+ ", jobId=" + jobId + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -577,8 +584,8 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("makeSession() error : sessionId="
-								+ sessionId + ", jobunitId=" + jobunitId
-								+ ", jobId=" + jobId + " SQLException");
+						+ sessionId + ", jobunitId=" + jobunitId
+						+ ", jobId=" + jobId + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
