@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.dao;
@@ -57,61 +57,63 @@ import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
  * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO
  */
 public class JobSessionJobDAOImpl implements JobSessionJobDAO {
-	
-	
+
+
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog(JobSessionJobDAOImpl.class);
-	
+	private static Log m_log = LogFactory.getLog(JobSessionJobDAOImpl.class);
+
+	@Override
 	public void init() {
 	}
-	
-	/** 
+
+	/**
 	 * SELECT文を発行します。
 	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK, com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobBean)
 	 */
+	@Override
 	public void load(JobSessionJobPK pk, JobSessionJobBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_session_job WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				//取得した値をBeanにセット
 				if(res.getTimestamp("end_date") != null)
 					ejb.setEnd_date(new Date(res.getTimestamp("end_date").getTime()));
 				else
 					ejb.setEnd_date(null);
-				
+
 				if(res.getString("end_status") != null){
 					ejb.setEnd_status(res.getInt("end_status"));
 				}else{
 					ejb.setEnd_status(null);
 				}
-				
+
 				if(res.getString("end_value") != null){
 					ejb.setEnd_value(res.getInt("end_value"));
 				}else{
 					ejb.setEnd_value(null);
 				}
-				
-				ejb.setEnd_staus_check_flg(res.getInt("end_staus_check_flg"));			
+
+				ejb.setEnd_staus_check_flg(res.getInt("end_staus_check_flg"));
 				ejb.setJob_id(res.getString("job_id"));
 				ejb.setJobunit_id(res.getString("jobunit_id"));
 				ejb.setResult(res.getString("result"));
@@ -123,7 +125,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 					ejb.setStart_date(null);
 				ejb.setStatus(res.getInt("status"));
 				ejb.setDelay_notify_flg(res.getInt("delay_notify_flg"));
-				
+
 			} else {
 				String msg = "JobSessionJob data is not found.";
 				m_log.error("load() error : " + pk.toString() + " SQLException " + msg);
@@ -151,21 +153,22 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		}
 		m_log.debug("load() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * UPDATE文を発行します。
 	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobBean)
 	 */
+	@Override
 	public void store(JobSessionJobBean ejb) throws EJBException {
 		m_log.debug("store() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
@@ -183,17 +186,17 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			sql.append("WHERE session_id = ? ");
 			sql.append("AND job_id = ?");
 			sql.append("AND jobunit_id = ?");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getScope_text());
 			stmt.setInt(2, ejb.getStatus());
-			if(ejb.getStart_date() instanceof java.util.Date)
+			if(ejb.getStart_date() != null)
 				stmt.setTimestamp(3, new Timestamp(ejb.getStart_date().getTime()));
 			else
 				stmt.setTimestamp(3, null);
-			if(ejb.getEnd_date() instanceof java.util.Date)
+			if(ejb.getEnd_date() != null)
 				stmt.setTimestamp(4, new Timestamp(ejb.getEnd_date().getTime()));
 			else
 				stmt.setTimestamp(4, null);
@@ -208,24 +211,24 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			stmt.setString(7, ejb.getResult());
 			stmt.setInt(8, ejb.getEnd_staus_check_flg());
 			stmt.setInt(9, ejb.getDelay_notify_flg());
-			
+
 			stmt.setString(10, ejb.getSession_id());
 			stmt.setString(11, ejb.getJob_id());
 			stmt.setString(12, ejb.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+					+ ", jobunitId=" + ejb.getJobunit_id()
+					+ ", jobId=" + ejb.getJob_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクローズ
@@ -238,8 +241,8 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -247,41 +250,42 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
 	}
-	
+
 	/**
 	 * DELETE文を発行します。
 	 * 引数で指定されたプライマリキーでデータベースから削除します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK)
 	 */
+	@Override
 	public void remove(JobSessionJobPK pk) throws RemoveException, EJBException {
 		m_log.debug("remove() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "DELETE FROM cc_job_session_job WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1 ) {
 				String msg = "result row is not 1";
 				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
-				throw new EJBException(msg);	
+				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
-			
+
 		} finally {
 			try {
 				if(stmt != null){
@@ -297,18 +301,19 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		}
 		m_log.debug("remove() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * INSERT文を発行します。
 	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobBean)
 	 */
+	@Override
 	public JobSessionJobPK create(JobSessionJobBean ejb) throws CreateException, EJBException {
 		m_log.debug("create() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		JobSessionJobPK pk;
@@ -330,19 +335,19 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			sql.append("delay_notify_flg, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getSession_id());
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setString(3, ejb.getScope_text());
 			stmt.setInt(4, ejb.getStatus());
-			if(ejb.getStart_date() instanceof java.util.Date)
+			if(ejb.getStart_date() != null)
 				stmt.setTimestamp(5, new Timestamp(ejb.getStart_date().getTime()));
 			else
 				stmt.setTimestamp(5, null);
-			if(ejb.getEnd_date() instanceof java.util.Date)
+			if(ejb.getEnd_date() != null)
 				stmt.setTimestamp(6, new Timestamp(ejb.getEnd_date().getTime()));
 			else
 				stmt.setTimestamp(6, null);
@@ -358,25 +363,25 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			stmt.setInt(10, ejb.getEnd_staus_check_flg());
 			stmt.setInt(11, ejb.getDelay_notify_flg());
 			stmt.setString(12, ejb.getJobunit_id());
-			
+
 			int row =	stmt.executeUpdate();
 			pk = new JobSessionJobPK(
 					ejb.getSession_id(),
 					ejb.getJobunit_id(),
 					ejb.getJob_id());
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -390,8 +395,8 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -400,7 +405,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 				+ ", jobId=" + ejb.getJob_id());
 		return pk;
 	}
-	
+
 	/**
 	 * 全件取得するSELECT文を発行します。
 	 * 取得したデータのプライマリキーをコレクションに格納し返します。
@@ -408,22 +413,23 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#findAll()
 	 */
+	@Override
 	public Collection findAll() throws FinderException {
 		m_log.debug("findAll() start : ");
-		
+
 		ArrayList<JobSessionJobPK> ret = new ArrayList<JobSessionJobPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_session_job";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobSessionJobPK pk= new JobSessionJobPK(
 						res.getString("session_id"),
@@ -432,7 +438,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
@@ -453,7 +459,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		m_log.debug("findAll() end : ");
 		return ret;
 	}
-	
+
 	/**
 	 * 1件取得するSELECT文を発行します。
 	 * 引数で指定されたプライマリキーで、データベースを検索します。
@@ -461,26 +467,27 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK)
 	 */
+	@Override
 	public JobSessionJobPK findByPrimaryKey(JobSessionJobPK pk) throws FinderException {
 		m_log.debug("findByPrimaryKey() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_session_job WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				return pk;
 			} else {
@@ -506,7 +513,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
 		}
 	}
-	
+
 	/**
 	 * 複数件取得するSELECT文を発行します。
 	 * 引数で指定されたセッションIDで、データベースを検索します。
@@ -514,26 +521,27 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobBean#ejbFindBySessionId(java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#findBySessionId(java.lang.String)
 	 */
+	@Override
 	public Collection findBySessionId(String sessionId) throws FinderException {
 		m_log.debug("findBySessionId() start : " + sessionId);
-		
+
 		ArrayList<JobSessionJobPK> ret = new ArrayList<JobSessionJobPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_session_job WHERE session_id = ?";
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, sessionId);
-			
+
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobSessionJobPK pk= new JobSessionJobPK(
 						res.getString("session_id"),
@@ -542,7 +550,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findBySessionId() error : " + sessionId + " SQLException");
 			throw new EJBException(e.getMessage());
@@ -563,7 +571,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		m_log.debug("findBySessionId() end : " + sessionId);
 		return ret;
 	}
-	
+
 	/**
 	 * 複数件取得するSELECT文を発行します。
 	 * 引数で指定された実行状態で、データベースを検索します。
@@ -571,30 +579,31 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobBean#ejbFindByStatus(java.lang.Integer)
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionJobDAO#findByStatus(java.lang.Integer)
 	 */
+	@Override
 	public Collection findByStatus(String sessionId, Integer status) throws FinderException {
 		m_log.debug("findByStatus() start : sessionId = " + sessionId + ", status = " + status);
-		
+
 		ArrayList<JobSessionJobPK> ret = new ArrayList<JobSessionJobPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("SELECT a.session_id, a.jobunit_id, a.job_id FROM cc_job_session_job as a, cc_job_session as b ");
 			sql.append("WHERE a.session_id = b.session_id AND a.job_id = b.job_id AND ");
 			sql.append("a.status = ? AND a.session_id = ?");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setInt(1, status);
 			stmt.setString(2, sessionId);
-			
+
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobSessionJobPK pk= new JobSessionJobPK(
 						res.getString("session_id"),
@@ -603,7 +612,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findByStatus() error : sessionId = " + sessionId + ", status = " + status, e);
 			throw new EJBException(e.getMessage());
@@ -624,7 +633,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		m_log.debug("findByStatus() end : sessionId = " + sessionId + ", status = " + status);
 		return ret;
 	}
-	
+
 	/**
 	 * ジョブセッションジョブを、ジョブマスタ、ジョブ待ち条件マスタ、ジョブコマンドマスタから作成します。
 	 * 
@@ -637,7 +646,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 	 */
 	public void makeSession(String sessionId, String jobunitId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
+
 		Connection conn = null;
 		Connection connMaster = null;
 		PreparedStatement stmt = null;
@@ -646,7 +655,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_session_job (");
@@ -663,7 +672,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			sql.append("delay_notify_flg, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1, sessionId);
@@ -674,7 +683,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			stmt.setInt(10, EndStatusCheckConstant.NO_WAIT_JOB);
 			stmt.setInt(11, DelayNotifyConstant.NONE);
 			stmt.setString(12, jobunitId);
-			
+
 			//SQL文の定義(マスタ検索)
 			StringBuilder sqlMaster = new StringBuilder();
 			sqlMaster.append("SELECT ");
@@ -689,28 +698,28 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			sqlMaster.append("left join cc_job_command_mst on (cc_job_mst.job_id=cc_job_command_mst.job_id AND cc_job_mst.jobunit_id=cc_job_command_mst.jobunit_id) ");
 			sqlMaster.append("WHERE  cc_job_mst.job_id= ? ");
 			sqlMaster.append("AND  cc_job_mst.jobunit_id= ? ");
-			
+
 			m_log.debug("makeSession() sqlMaster : sql=" + sqlMaster.toString());
-			
+
 			//SQL文のセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sqlMaster.toString());
-			
+
 			//リポジトリ(RepositoryControllerLocal)を取得
-			RepositoryControllerLocal repository = 
+			RepositoryControllerLocal repository =
 				RepositoryControllerUtil.getLocalHome().create();
-			
+
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
 				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
-				
+
 				//SQL文のセット(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				stmtMaster.setString(2, jobunitId);
 				//SQL実行(マスタ検索)
 				ResultSet resMaster = stmtMaster.executeQuery();
-				
+
 				if (resMaster.next()) {
 					//SQL文のセット(INSERT)
 					stmt.setString(2, jobId);
@@ -722,7 +731,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 					}else{
 						stmt.setString(3, null);
 					}
-					
+
 					//実行状態・終了値を設定
 					if(resMaster.getInt("suspend") == YesNoConstant.TYPE_YES){
 						//保留
@@ -739,7 +748,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 						stmt.setInt(4, StatusConstant.TYPE_WAIT);
 						stmt.setNull(7, Types.INTEGER);
 					}
-					
+
 					//INSERTを実行
 					int row =	stmt.executeUpdate();
 					if (row != 1) {
@@ -780,7 +789,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			}
 		}
 		m_log.debug("makeSession() end : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
+
 	}
 }
 
