@@ -1,15 +1,15 @@
 /*
 Copyright (C) 2010 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
-*/
+ */
 
 package com.clustercontrol.nodemap.ejb.session;
 
@@ -28,11 +28,10 @@ import javax.naming.NamingException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.BgFileNotFoundException;
-import com.clustercontrol.FacilityNotFoundException;
-import com.clustercontrol.HinemosUnknownException;
-import com.clustercontrol.IconFileNotFoundException;
-import com.clustercontrol.bean.FacilityConstant;
+import com.clustercontrol.fault.BgFileNotFound;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.IconFileNotFound;
 import com.clustercontrol.nodemap.NodeMapException;
 import com.clustercontrol.nodemap.ejb.entity.AssociationLocal;
 import com.clustercontrol.nodemap.ejb.entity.AssociationPK;
@@ -51,6 +50,7 @@ import com.clustercontrol.nodemap.bean.FacilityElement;
 import com.clustercontrol.nodemap.bean.NodeMapModel;
 import com.clustercontrol.nodemap.bean.NodeElement;
 import com.clustercontrol.nodemap.bean.ScopeElement;
+import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.FacilityLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityRelationLocal;
@@ -64,57 +64,51 @@ import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
  *
  * <!-- begin-user-doc --> マップ情報の制御を行うsession bean <!-- end-user-doc --> *
  *
- * <!-- begin-xdoclet-definition --> 
- * @ejb.bean name="NodeMapController"	
+ * <!-- begin-xdoclet-definition -->
+ * @ejb.bean name="NodeMapController"
  *           jndi-name="NodeMapController"
- *           type="Stateless" 
+ *           type="Stateless"
  *           transaction-type="Container"
+ *           view-type="local"
  * 
- * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=AccessController"
+ * @ejb.transaction type="Required"
  * 
  * @ejb.permission
  *     unchecked="true"
- *     method-intf="Home"
- *     
- * @ejb.permission
- *     unchecked="true"
  *     method-intf="LocalHome"
- *     
+ * 
  * @ejb.permission
  *     unchecked="true"
  *     method-intf="Local"
  * 
- * <!-- end-xdoclet-definition --> 
+ * <!-- end-xdoclet-definition -->
  * @generated
  */
 public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
-	protected static Log m_log = LogFactory.getLog( NodeMapControllerBean.class );
+	private static Log m_log = LogFactory.getLog( NodeMapControllerBean.class );
 
 	@SuppressWarnings("unused")
 	private SessionContext m_context;
 	private final int MAX_FILENAME = 64;
 
+	@Override
 	public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException {
 		m_context = ctx;
 	}
 
 	/**
 	 * リポジトリ情報からマップのデータを生成します。<BR>
-	 *  
-	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
+	 * @ejb.interface-method
 	 * 
 	 * @param parentFacilityId 描画対象スコープの親のファシリティID
 	 * @param facilityId 描画対象スコープのファシリティID
 	 * @return マップ描画用データ
-	 * @throws HinemosUnknownException 
+	 * @throws HinemosUnknown
 	 * 
 	 * @see com.clustercontrol.nodemap.model.NodeMapModel
 	 */
-	public NodeMapModel createNodeMapModel(String facilityId) throws HinemosUnknownException {
+	public NodeMapModel createNodeMapModel(String facilityId) throws HinemosUnknown {
 		m_log.debug("createNodeMap() start : " + facilityId);
 
 		NodeMapModel map = null;
@@ -125,7 +119,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			RepositoryControllerLocal rep = RepositoryControllerUtil.getLocalHome().create();
 			String facilityPath = rep.getFacilityPath(facilityId, null);
 			m_log.debug("facilityPath = " + facilityPath);
-			
+
 			// リポジトリからスコープのファシリティ名を取得する
 			String facilityName = "";
 			if(FacilityConstant.STRING_COMPOSITE.equals(facilityId)){
@@ -136,7 +130,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				facilityName = bean.getFacilityName();
 			}
 			m_log.debug("facilityName = " + facilityName);
-			
+
 			String parentFacilityId = null;
 			// 親のファシリティのIDを取得する
 			if(FacilityConstant.STRING_COMPOSITE.equals(facilityId)){ // トップスコープの場合は、親はなし
@@ -146,7 +140,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				parentFacilityId = getParentId(facilityId);
 				m_log.debug("parentFacilityId = " + parentFacilityId);
 			}
-			
+
 			// 新規にマップを生成する
 			map = new NodeMapModel(parentFacilityId, facilityId, facilityName, facilityPath);
 		} catch (FinderException e) {
@@ -158,7 +152,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			m_log.error("createNodeMapModel() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 
 		m_log.debug("createNodeMapModel() end");
@@ -167,22 +161,18 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 
 	/**
 	 * マップのデータをDBに登録します。<BR>
-	 *  
-	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryWrite"
-	 *     method-intf="Remote"
+	 * @ejb.interface-method
 	 * 
 	 * @param facilityId 描画対象スコープのファシリティID
 	 * @return マップ描画用データ
-	 * @throws HinemosUnknownException 
+	 * @throws HinemosUnknown
 	 * 
 	 * @see com.clustercontrol.nodemap.model.NodeMapModel
 	 */
-	public void registerNodeMapModel(NodeMapModel map) throws HinemosUnknownException {
+	public void registerNodeMapModel(NodeMapModel map) throws HinemosUnknown {
 		String mapId = map.getMapId();
-		
+
 		// 登録時は、該当のマップの関係（コネクション）と要素を全て削除した後、登録する。
 		try {
 			// 関係を削除
@@ -206,7 +196,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			m_log.error("registerNodeMapModel() ((AssociationLocal)bean).remove() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 
 		try {
@@ -231,7 +221,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			m_log.error("registerNodeMapModel() ((FacilityPositionLocal)bean).remove() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 
 		try {
@@ -258,11 +248,11 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			m_log.error("registerNodeMapModel() MapInfoUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 
 		// エレメントを更新
-		FacilityElement[] elemet = map.getContents();
+		FacilityElement[] elemet = map.getContentArray();
 		for(int i=0; i<elemet.length; i++){
 			FacilityPositionLocal posi = null;
 			try {
@@ -287,7 +277,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 					m_log.error("registerNodeMapModel() FacilityPositionUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
 							", " + e.getMessage(), e);
 					m_context.setRollbackOnly();
-					throw new HinemosUnknownException(e1.getMessage(), e1);
+					throw new HinemosUnknown(e1.getMessage(), e1);
 				}
 			} catch (NamingException e) {
 				m_log.error("registerNodeMapModel() FacilityPositionUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
@@ -297,37 +287,39 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 		}
 
 		// 関連を更新
-		for (Association asso : map.getAssociations()) {
-			try {
-				AssociationUtil.getLocalHome().findByPrimaryKey(
-						new AssociationPK(mapId, asso.getSource(), asso.getTarget()));
-			} catch (FinderException e) {
-				// 無い場合は新規に作成
+		if (map.getAssociations() != null) {
+			for (Association asso : map.getAssociations()) {
 				try {
-					AssociationUtil.getLocalHome().create(
-							mapId,
-							asso.getSource(),
-							asso.getTarget()
-					);
-				} catch (CreateException e1) {
+					AssociationUtil.getLocalHome().findByPrimaryKey(
+							new AssociationPK(mapId, asso.getSource(), asso.getTarget()));
+				} catch (FinderException e) {
+					// 無い場合は新規に作成
+					try {
+						AssociationUtil.getLocalHome().create(
+								mapId,
+								asso.getSource(),
+								asso.getTarget()
+						);
+					} catch (CreateException e1) {
+						m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+								", " + e.getMessage(), e);
+						m_context.setRollbackOnly();
+					} catch (Exception e1) {
+						m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+								", " + e.getMessage(), e);
+						m_context.setRollbackOnly();
+						throw new HinemosUnknown(e1.getMessage(), e1);
+					}
+				} catch (NamingException e) {
 					m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
 							", " + e.getMessage(), e);
 					m_context.setRollbackOnly();
-				} catch (Exception e1) {
-					m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
-							", " + e.getMessage(), e);
-					m_context.setRollbackOnly();
-					throw new HinemosUnknownException(e1.getMessage(), e1);
 				}
-			} catch (NamingException e) {
-				m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
-						", " + e.getMessage(), e);
-				m_context.setRollbackOnly();
 			}
 		}
-		
+
 		// アイコンを更新
-		for (FacilityElement element : map.getContents()) {
+		for (FacilityElement element : map.getContentArray()) {
 			String facilityId = element.getFacilityId();
 			String iconImage = element.getIconImage();
 			if (iconImage == null) {
@@ -344,7 +336,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				m_log.error("registerNodeMapModel() : " + e.getClass().getSimpleName() +
 						", " + e.getMessage(), e);
 				m_context.setRollbackOnly();
-				throw new HinemosUnknownException(e.getMessage(), e);
+				throw new HinemosUnknown(e.getMessage(), e);
 			}
 			if (!iconImage.equals(bean.getIconImage())) {
 				bean.setIconImage(iconImage);
@@ -354,22 +346,18 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 
 	/**
 	 * マップのデータを取得します。<BR>
-	 *  
-	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
+	 * @ejb.interface-method
 	 * 
 	 * @param facilityId 描画対象スコープのファシリティID
 	 * @return マップ描画用データ
-	 * @throws NodeMapException 
+	 * @throws NodeMapException
 	 * 
 	 * @see com.clustercontrol.nodemap.model.NodeMapModel
 	 */
-	public NodeMapModel getNodeMapModel(String facilityId) throws HinemosUnknownException, NodeMapException {
+	public NodeMapModel getNodeMapModel(String facilityId) throws HinemosUnknown, NodeMapException {
 		m_log.debug("getNodeMap() start");
-		
+
 		// facilityIdが履歴には存在するが、リポジトリに存在しない場合をチェック。
 		try {
 			if (!FacilityConstant.STRING_COMPOSITE.equals(facilityId)) {
@@ -380,9 +368,9 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			throw new NodeMapException ("cannot find " + facilityId, e);
 		} catch (Exception e) {
 			m_log.error("getNodeMapModel " + e.getMessage(), e);
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
-		
+
 		// リポジトリ情報をもとにマップを生成
 		NodeMapModel map = createNodeMapModel(facilityId);
 		String mapId = facilityId;
@@ -400,43 +388,43 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 
 				// 指定のスコープ配下のスコープおよびノードの一覧を取得する
 				ArrayList<String> facilityIdList = RepositoryControllerUtil.
-						getLocalHome().create().getFacilityIdList(facilityId, 1);
+				getLocalHome().create().getFacilityIdList(facilityId, 1);
 				for (String fid : facilityIdList) {
 					// エレメントを生成
 					FacilityElement element = createElementForRepository(facilityId, fid);
 					// 座標未登録ノードを追加
 					map.addContent(element);
 				}
-			} catch (FacilityNotFoundException e1) {
+			} catch (FacilityNotFound e1) {
 				map = new NodeMapModel("", "", "Could not create a map.", "-");
 			} catch (CreateException e1) {
 				m_log.error(e1.getMessage(), e1);
 				map = new NodeMapModel("", "", "Could not create a map.", "-");
 			} catch (Exception e1) {
 				m_log.error("getNodeMapModel " + e.getMessage(), e1);
-				throw new HinemosUnknownException(e.getMessage(), e1);
+				throw new HinemosUnknown(e.getMessage(), e1);
 			}
 			return map;
 		} catch (Exception e) {
 			m_log.error("getodeMapModel " + e.getMessage(), e);
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 
 		// 背景イメージ名を設定する
 		map.setBgName(bean.getBackgroundImage());
-		
+
 		ArrayList<String> childList = null;
 		try {
 			childList = RepositoryControllerUtil.
-					getLocalHome().create().getFacilityIdList(facilityId, 1);
+			getLocalHome().create().getFacilityIdList(facilityId, 1);
 		} catch (CreateException e3) {
 			m_log.error(e3.getMessage(), e3);
 			map = new NodeMapModel("", "", "Could not create a map.", "-");
 		} catch (Exception e) {
 			m_log.error("getodeMapModel " + e.getMessage(), e);
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
-		
+
 		for (String childId : childList) {
 			String parentId = facilityId;
 
@@ -458,15 +446,15 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 
 					// 座標未登録ノードを追加
 					map.addContent(element);
-				} catch (FacilityNotFoundException e2) {
+				} catch (FacilityNotFound e2) {
 					// 何もしない。
 				} catch (Exception e2) {
 					m_log.error("getNodeMapModel " + e2.getMessage(), e2);
-					throw new HinemosUnknownException(e2.getMessage(), e2);
+					throw new HinemosUnknown(e2.getMessage(), e2);
 				}
 			} catch (Exception e) {
 				m_log.error("getNodeMapModel " + e.getMessage(), e);
-				throw new HinemosUnknownException(e.getMessage(), e);
+				throw new HinemosUnknown(e.getMessage(), e);
 			}
 		}
 
@@ -496,47 +484,39 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 
 	/**
 	 * 背景データを取得します。<BR>
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
-	 * 
-	 * @param filename 
+	 * @param filename
 	 * @return filedata
-	 * @throws BgFileNotFoundException 
+	 * @throws BgFileNotFound
 	 */
-	public byte[] getBgImage(String filename) throws HinemosUnknownException, BgFileNotFoundException {
+	public byte[] getBgImage(String filename) throws HinemosUnknown, BgFileNotFound {
 		// 背景のバイナリデータを取得
 		try {
 			BgImageLocal bean = BgImageUtil.getLocalHome().findByPrimaryKey(filename);
 			return bean.getFiledata();
 		} catch (FinderException e) {
 			m_log.warn("getBgImage " + e.getMessage(),e);
-			throw new BgFileNotFoundException(e.getMessage(),e);
+			throw new BgFileNotFound(e.getMessage(),e);
 		} catch (Exception e) {
 			m_log.error("getBgImage " + e.getMessage(), e);
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 	}
 
 
 	/**
 	 * 背景データをDBに登録します。<BR>
-	 *  
-	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryWrite"
-	 *     method-intf="Remote"
+	 * @ejb.interface-method
 	 * 
 	 * @param filename
 	 * @param filedata
-	 * @throws HinemosUnknownException 
-	 * @throws NodeMapException 
+	 * @throws HinemosUnknown
+	 * @throws NodeMapException
 	 */
-	public void setBgImage(String filename, byte[] filedata) throws HinemosUnknownException, NodeMapException {
+	public void setBgImage(String filename, byte[] filedata) throws HinemosUnknown, NodeMapException {
 		if (filename != null && filename.length() > MAX_FILENAME) {
 			String[] args = { Integer.toString(MAX_FILENAME) };
 			throw new NodeMapException(
@@ -554,29 +534,25 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				m_log.error("setBgImage() : " + e.getClass().getSimpleName() +
 						", " + e.getMessage(), e);
 				m_context.setRollbackOnly();
-				throw new HinemosUnknownException(e1.getMessage(),e1);
+				throw new HinemosUnknown(e1.getMessage(),e1);
 			}
 		} catch (Exception e) {
 			m_log.error("setBgImage() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(),e);
+			throw new HinemosUnknown(e.getMessage(),e);
 		}
 	}
 
 	/**
 	 * 背景画像のファイル名一覧を取得します。<BR>
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
-	 * 
 	 * @return Collection<String>
-	 * @throws HinemosUnknownException 
+	 * @throws HinemosUnknown
 	 */
-	public Collection<String> getBgImagePK() throws HinemosUnknownException {
+	public Collection<String> getBgImagePK() throws HinemosUnknown {
 		// 背景のPKを取得
 		ArrayList<String> filenameArray = new ArrayList<String>();
 		Collection<BgImageLocal> beanCollection = null;
@@ -584,7 +560,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			beanCollection = BgImageUtil.getLocalHome().findAll();
 		} catch (Exception e) {
 			m_log.error("getBgImagePK " + e.getMessage(), e);
-			throw new HinemosUnknownException(e.getMessage(),e);
+			throw new HinemosUnknown(e.getMessage(),e);
 		}
 		for (BgImageLocal bean : beanCollection) {
 			filenameArray.add((String)bean.getPrimaryKey());
@@ -595,16 +571,12 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 
 	/**
 	 * 背景画像のファイル名の存在有無を取得します。<BR>
-	 *  
-	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
+	 * @ejb.interface-method
 	 * 
 	 * @return boolean
 	 */
-	public boolean isBgImage(String filename) throws HinemosUnknownException {
+	public boolean isBgImage(String filename) throws HinemosUnknown {
 		// 背景のバイナリデータを取得
 		try {
 			BgImageUtil.getLocalHome().findByPrimaryKey(filename);
@@ -614,56 +586,48 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			m_log.error("isBgImage() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(),e);
+			throw new HinemosUnknown(e.getMessage(),e);
 		}
 		return true;
 	}
 
 	/**
 	 * アイコン画像を取得します。<BR>
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
-	 * 
-	 * @param filename 
+	 * @param filename
 	 * @return filedata
-	 * @throws HinemosUnknownException 
-	 * @throws IconFileNotFoundException 
+	 * @throws HinemosUnknown
+	 * @throws IconFileNotFound
 	 */
-	public byte[] getIconImage(String filename) throws HinemosUnknownException, IconFileNotFoundException {
+	public byte[] getIconImage(String filename) throws HinemosUnknown, IconFileNotFound {
 		// 背景のバイナリデータを取得
 		IconImageLocal bean = null;
 		try {
 			bean = IconImageUtil.getLocalHome().findByPrimaryKey(filename);
 		} catch (FinderException e) {
 			m_log.warn("getIconImage " + e.getMessage());
-			throw new IconFileNotFoundException(e.getMessage(),e);
+			throw new IconFileNotFound(e.getMessage(),e);
 		} catch (Exception e) {
 			m_log.error("getIconImage " + e.getMessage(),e);
-			throw new HinemosUnknownException(e.getMessage(),e);
+			throw new HinemosUnknown(e.getMessage(),e);
 		}
 		return bean.getFiledata();
 	}
 
 	/**
 	 * アイコン画像をDBに登録します。<BR>
-	 *  
-	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryWrite"
-	 *     method-intf="Remote"
+	 * @ejb.interface-method
 	 * 
 	 * @param filename
 	 * @param filedata
-	 * @throws NodeMapException 
-	 * @throws HinemosUnknownException 
+	 * @throws NodeMapException
+	 * @throws HinemosUnknown
 	 * 
 	 */
-	public void setIconImage(String filename, byte[] filedata) throws NodeMapException, HinemosUnknownException {
+	public void setIconImage(String filename, byte[] filedata) throws NodeMapException, HinemosUnknown {
 		if (filename != null && filename.length() > MAX_FILENAME) {
 			String[] args = { Integer.toString(MAX_FILENAME) };
 			throw new NodeMapException(
@@ -681,29 +645,25 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				m_log.error("setIconImage() : " + e.getClass().getSimpleName() +
 						", " + e.getMessage(), e);
 				m_context.setRollbackOnly();
-				throw new HinemosUnknownException(e1.getMessage(),e1);
+				throw new HinemosUnknown(e1.getMessage(),e1);
 			}
 		} catch (Exception e) {
 			m_log.error("setIconImage() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(),e);
+			throw new HinemosUnknown(e.getMessage(),e);
 		}
 	}
 
 	/**
 	 * アイコンのファイル名一覧を取得します。<BR>
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
-	 * 
 	 * @return Collection<String>
-	 * @throws HinemosUnknownException 
+	 * @throws HinemosUnknown
 	 */
-	public Collection<String> getIconImagePK() throws HinemosUnknownException {
+	public Collection<String> getIconImagePK() throws HinemosUnknown {
 		// アイコンのPKを取得
 		ArrayList<String> filenameArray = new ArrayList<String>();
 		Collection<IconImageLocal> beanCollection = null;
@@ -711,7 +671,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			beanCollection = IconImageUtil.getLocalHome().findAll();
 		} catch (Exception e) {
 			m_log.error("getIconImagePK " + e.getMessage(),e);
-			throw new HinemosUnknownException(e.getMessage(),e);
+			throw new HinemosUnknown(e.getMessage(),e);
 		}
 		for (IconImageLocal bean : beanCollection) {
 			filenameArray.add((String)bean.getPrimaryKey());
@@ -722,17 +682,13 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 
 	/**
 	 * アイコンのファイル名の存在有無を取得します。<BR>
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @ejb.permission
-	 *     role-name="RepositoryRead"
-	 *     method-intf="Remote"
-	 * 
 	 * @return boolean
-	 * @throws HinemosUnknownException 
+	 * @throws HinemosUnknown
 	 */
-	public boolean isIconImage(String filename) throws HinemosUnknownException {
+	public boolean isIconImage(String filename) throws HinemosUnknown {
 		// アイコンの存在有無を確認
 		try {
 			IconImageUtil.getLocalHome().findByPrimaryKey(filename);
@@ -746,7 +702,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			m_log.error("isIconImage() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage(), e);
 			m_context.setRollbackOnly();
-			throw new HinemosUnknownException(e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 		return true;
 	}
@@ -765,7 +721,7 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				FacilityTreeAttributeConstant.INTERNAL_SCOPE.equals(targetId)) {
 			return FacilityConstant.STRING_COMPOSITE;
 		}
-		
+
 		FacilityLocal bean = null;
 		try {
 			bean = FacilityUtil.getLocalHome().findByPrimaryKey(targetId);
@@ -776,10 +732,10 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			m_log.error(e.getMessage(), e);
 			return null;
 		}
-		
+
 		Collection<FacilityRelationLocal> parentBeanCol =
 			bean.getFacilityRelationAsChild();
-		
+
 		/*
 		 * スコープの親は必ず一個。
 		 * 最上位スコープの一段下のみ、親はFacilityRelationLocalから取得できない。
@@ -793,11 +749,11 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			return null;
 		}
 		FacilityRelationLocal parentBean = (FacilityRelationLocal)(parentBeanCol.toArray())[0];
-		
+
 		return parentBean.getParentFacilityId();
 	}
 
-	private FacilityElement createElementForRepository(String parentId, String fid) throws HinemosUnknownException, FacilityNotFoundException {
+	private FacilityElement createElementForRepository(String parentId, String fid) throws HinemosUnknown, FacilityNotFound {
 		FacilityElement element;
 		// 属性値取得用のエンティティビーン
 		FacilityLocal facilityEntity;
@@ -805,12 +761,12 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			facilityEntity = FacilityUtil.getLocalHome().findByPrimaryKey(fid);
 		} catch (FinderException e) {
 			m_log.warn("createElementForRepository " + e.getMessage());
-			throw new FacilityNotFoundException(e.getMessage(),e);
+			throw new FacilityNotFound(e.getMessage(),e);
 		} catch (Exception e) {
 			m_log.error("createElementForRepository " + e.getMessage(),e);
-			throw new HinemosUnknownException(e.getMessage(),e);
+			throw new HinemosUnknown(e.getMessage(),e);
 		}
-		
+
 		// アイコン名を取得
 		String facilityName = facilityEntity.getFacilityName();
 		String iconImage = null;
@@ -824,16 +780,16 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			element = new ScopeElement(parentId, fid, facilityName, "scope", true);
 		} else {  // ノードの場合
 			m_log.debug("Node : " + facilityName + "(" + fid + ")");
-			
+
 			NodeLocal nodeEntity = null;
 			try {
 				nodeEntity = NodeUtil.getLocalHome().findByPrimaryKey(fid);
 			} catch (FinderException e) {
 				m_log.warn("createElementForRepository " + e.getMessage());
-				throw new FacilityNotFoundException(e.getMessage(),e);
+				throw new FacilityNotFound(e.getMessage(),e);
 			} catch (Exception e) {
 				m_log.error("createElementForRepository " + e.getMessage(),e);
-				throw new HinemosUnknownException(e.getMessage(), e);
+				throw new HinemosUnknown(e.getMessage(), e);
 			}
 			boolean valid = facilityEntity.isValid();
 			iconImage = nodeEntity.getIconImage();
