@@ -3,12 +3,12 @@
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
 
  */
@@ -19,21 +19,16 @@ import java.util.Collection;
 
 import javax.ejb.FinderException;
 import javax.ejb.RemoveException;
-import javax.jms.DeliveryMode;
-import javax.jms.JMSException;
 import javax.naming.NamingException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.NotifyNotFoundException;
-import com.clustercontrol.accesscontrol.factory.AccessLock;
-import com.clustercontrol.commons.util.SendQueue;
-import com.clustercontrol.notify.bean.NotifyInfoContext;
-import com.clustercontrol.notify.bean.QueueConstant;
+import com.clustercontrol.fault.NotifyNotFound;
+import com.clustercontrol.notify.ejb.entity.NotifyHistoryLocal;
+import com.clustercontrol.notify.ejb.entity.NotifyHistoryUtil;
 import com.clustercontrol.notify.ejb.entity.NotifyInfoLocal;
 import com.clustercontrol.notify.ejb.entity.NotifyInfoUtil;
-import com.clustercontrol.notify.util.NotifyInfoCache;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -45,7 +40,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 public class DeleteNotify {
 
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog( DeleteNotify.class );
+	private static Log m_log = LogFactory.getLog( DeleteNotify.class );
 
 	/**
 	 * 通知情報を削除します。
@@ -60,26 +55,23 @@ public class DeleteNotify {
 	 * 
 	 * @param notifyId 削除対象の通知ID
 	 * @return 削除に成功した場合、<code> true </code>
-	 * @throws NotifyNotFoundException
+	 * @throws NotifyNotFound
 	 * @throws RemoveException
 	 * @throws NamingException
+	 * @throws FinderException
 	 * @throws JMSException
 	 * 
 	 * @see com.clustercontrol.notify.ejb.entity.NotifyInfoBean
 	 * @see com.clustercontrol.notify.ejb.entity.NotifyEventInfoBean
 	 * @see #deleteEvents(Collection)
-	 * @see com.clustercontrol.notify.bean.NotifyInfoContext#NotifyInfoContext(int, java.lang.String, com.clustercontrol.notify.bean.NotifyInfo)
 	 * @see com.clustercontrol.notify.util.SendQueue
 	 */
-	public boolean delete(String notifyId) throws NotifyNotFoundException, RemoveException, NamingException, JMSException {
-		//アクセスロック
-		AccessLock.lock(AccessLock.NOTIFY);
+	public boolean delete(String notifyId) throws NotifyNotFound, RemoveException, NamingException, FinderException {
 
 		NotifyInfoLocal notify = null;
-		SendQueue queue = null;
-		try 
+		try
 		{
-			// 通知イベント情報を取得
+			// 通知設定を取得
 			notify = NotifyInfoUtil.getLocalHome().findByPrimaryKey(notifyId);
 
 		} catch (FinderException e) {
@@ -87,7 +79,7 @@ public class DeleteNotify {
 			String[] args = { notifyId };
 			apllog.put("SYS", "003", args);
 			m_log.debug("delete():" + e.getMessage());
-			throw new NotifyNotFoundException(e.getMessage(), e);
+			throw new NotifyNotFound(e.getMessage(), e);
 		} catch (NamingException e) {
 			AplLogger apllog = new AplLogger("NOTIFY", "notify");
 			String[] args = { notifyId };
@@ -96,63 +88,34 @@ public class DeleteNotify {
 			throw e;
 		}
 
-		try 
+		try
 		{
-			NotifyInfoCache.clear();
-			
-			// 関連情報を削除
-			deleteRelation(notifyId);
+			// 通知関連情報を削除
+			DeleteNotifyRelation deleteRelation = new DeleteNotifyRelation();
+			deleteRelation.deleteBaseOnNotifyId(notifyId);
+
+			// この通知設定の結果として通知された通知履歴を削除する
+			Collection<NotifyHistoryLocal> historyList =
+				NotifyHistoryUtil.getLocalHome().findByNotifyId(notify.getNotifyId());
+			for(NotifyHistoryLocal history : historyList){
+				history.remove();
+			}
 
 			// 通知情報を削除
 			notify.remove();
-
-			NotifyInfoContext context = new NotifyInfoContext(NotifyInfoContext.TYPE_DELETE, notifyId, null);
-
-			// 通知情報キャッシュを更新
-			// FIXME Notification Cache will be removed
-			queue = new SendQueue(QueueConstant.QUEUE_NAME_NOTIFYCONTROL);
-			queue.put(context, DeliveryMode.PERSISTENT);
-			queue.terminate();
-			
-			queue = new SendQueue(QueueConstant.QUEUE_NAME_NOTIFYCONTROL_NON_PERSISTENCE);
-			queue.put(context, DeliveryMode.PERSISTENT);
-			queue.terminate();
-
 		} catch (RemoveException e) {
 			AplLogger apllog = new AplLogger("NOTIFY", "notify");
 			String[] args = { notifyId };
 			apllog.put("SYS", "003", args);
 			m_log.debug("getNotify():" + e.getMessage());
 			throw e;
-		} catch (JMSException e) {
+		} catch (FinderException e) {
 			AplLogger apllog = new AplLogger("NOTIFY", "notify");
 			String[] args = { notifyId };
 			apllog.put("SYS", "003", args);
-			m_log.debug("add():" + e.getMessage());
+			m_log.debug("getNotify():" + e.getMessage());
 			throw e;
 		}
-		finally{
-			if(queue != null){
-				queue.terminate();	
-			}
-		}
-		return true;
-	}
-
-	/**
-	 * 関連情報を削除します。
-	 * 
-	 * @param notifyId
-	 * @return 削除に成功した場合、</code> true </code>
-	 * 
-	 * @see com.clustercontrol.notify.factory.DeleteNotifyRelation
-	 */
-
-	private boolean deleteRelation(String notifyId) {
-		// 通知関連情報を削除
-		DeleteNotifyRelation deleteRelation = new DeleteNotifyRelation();
-		deleteRelation.deleteBaseOnNotifyId(notifyId);
-
 		return true;
 	}
 }
